@@ -15,18 +15,22 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "cpp.h"
+
 #ifdef _WIN32
 #include "boinc_win.h"
-#else
+#else 
 #include "config.h"
 #endif
 
 #include <cstring>
+
 #include "parse.h"
 #include "error_numbers.h"
 #include "client_msgs.h"
 #include "str_util.h"
 #include "str_replace.h"
+#include "url.h"
 #include "file_names.h"
 #include "filesys.h"
 #include "client_state.h"
@@ -73,7 +77,7 @@ int ACCT_MGR_OP::do_rpc(
         for (i=0; i<gstate.projects.size(); i++) {
             PROJECT* p = gstate.projects[i];
             p->attached_via_acct_mgr = false;
-            p->ams_resource_share = 0;
+            p->ams_resource_share = -1;
         }
         return 0;
     }
@@ -233,7 +237,7 @@ int AM_ACCOUNT::parse(XML_PARSER& xp) {
             continue;
         }
         if (xp.parse_double(tag, "resource_share", dtemp)) {
-            if (dtemp > 0) {
+            if (dtemp >= 0) {
                 resource_share.set(dtemp);
             } else {
                 msg_printf(NULL, MSG_INFO,
@@ -689,4 +693,3 @@ bool ACCT_MGR_INFO::poll() {
     return false;
 }
 
-const char *BOINC_RCSID_8fd9e873bf="$Id: acct_mgr.cpp 18437 2009-06-16 20:54:44Z davea $";
