@@ -15,11 +15,11 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "cpp.h"
+
 #ifdef _WIN32
 #include "boinc_win.h"
-#endif
-
-#ifndef _WIN32
+#else 
 #include "config.h"
 #endif
 
@@ -29,6 +29,7 @@
 #include "parse.h"
 #include "filesys.h"
 #include "str_util.h"
+#include "url.h"
 #include "util.h"
 #include "client_msgs.h"
 #include "log_flags.h"
@@ -39,6 +40,7 @@ void PROJECT_INIT::clear() {
     strcpy(url, "");
     strcpy(name, "");
     strcpy(account_key, "");
+    strcpy(team_name, "");
 }
 
 PROJECT_INIT::PROJECT_INIT() {
@@ -57,6 +59,7 @@ int PROJECT_INIT::init() {
         while(mf.fgets(buf, sizeof(buf))) {
             if (match_tag(buf, "</project_init>")) break;
             else if (parse_str(buf, "<name>", name, 256)) continue;
+            else if (parse_str(buf, "<team_name>", team_name, 256)) continue;
             else if (parse_str(buf, "<url>", url, 256)) {
                 canonicalize_master_url(url);
                 continue;
@@ -65,6 +68,7 @@ int PROJECT_INIT::init() {
             }
         }
         fclose(p);
+        msg_printf(0, MSG_INFO, "Found project_init.xml for %s", url);
     }
     return 0;
 }
@@ -84,6 +88,7 @@ void ACCOUNT_IN::parse(char* buf) {
     parse_str(buf, "<email_addr>", email_addr);
     parse_str(buf, "<passwd_hash>", passwd_hash);
     parse_str(buf, "<user_name>", user_name);
+    parse_str(buf, "<team_name>", team_name);
     canonicalize_master_url(url);
 }
 
@@ -175,7 +180,13 @@ int CREATE_ACCOUNT_OP::do_rpc(ACCOUNT_IN& ai) {
     escape_url(parameter);
     url += parameter;
 
-    retval = gui_http->do_rpc(this, url, CREATE_ACCOUNT_FILENAME);
+    if (!ai.team_name.empty()) {
+        url += "&team_name=";
+        parameter = ai.team_name;
+        escape_url(parameter);
+        url += parameter;
+    }
+    retval = gui_http->do_rpc(this, (char*)url.c_str(), CREATE_ACCOUNT_FILENAME);
     if (retval) {
         error_num = retval;
     } else {
@@ -244,26 +255,24 @@ void GET_CURRENT_VERSION_OP::handle_reply(int http_op_retval) {
     }
     gstate.new_version_check_time = gstate.now;
     FILE* f = boinc_fopen(GET_CURRENT_VERSION_FILENAME, "r");
-    if (f) {
-        while (fgets(buf, 256, f)) {
-            if (match_tag(buf, "<version>")) {
-                if (parse_version(f, new_version)) {
-                    msg_printf(0, MSG_USER_ERROR,
-                        "A new version of BOINC (%s) is available for your computer",
-                        new_version
-                    );
-
-                    msg_printf(0, MSG_USER_ERROR,
-                        "Visit %s to get it.",
-						config.client_download_url.c_str()
-                    );
-                    gstate.newer_version = string(new_version);
-                    break;
-                }
+    if (!f) return;
+    while (fgets(buf, 256, f)) {
+        if (match_tag(buf, "<version>")) {
+            if (parse_version(f, new_version)) {
+                msg_printf(0, MSG_INFO,
+                    "A new version of BOINC (%s) is available",
+                    new_version
+                );
+                msg_printf(0, MSG_INFO,
+                    "Visit %s to download it",
+                    config.client_download_url.c_str()
+                );
+                gstate.newer_version = string(new_version);
+                break;
             }
         }
-        fclose(f);
     }
+    fclose(f);
 }
 
 #define NEW_VERSION_CHECK_PERIOD (14*86400)
@@ -329,4 +338,3 @@ void CLIENT_STATE::all_projects_list_check() {
     get_project_list_op.do_rpc();
 }
 
-const char *BOINC_RCSID_84df3fc17e="$Id: acct_setup.cpp 19245 2009-10-05 20:05:44Z romw $";
