@@ -18,16 +18,12 @@
 #ifndef CLIENT_MSG_LOG_H
 #define CLIENT_MSG_LOG_H
 
-// write messages ONLY as follows:
-// if (log_flags.X) {
-//     msg_printf();
-// }
-
 #include <algorithm>
 #include <deque>
 #include <string>
 #include <string.h>
 
+#include "common_defs.h"
 #include "log_flags.h"
 
 class PROJECT;
@@ -46,6 +42,7 @@ struct MESSAGE_DESC {
 extern std::deque<MESSAGE_DESC*> message_descs;
 extern void record_message(class PROJECT *p, int priority, int now, char* msg);
 extern void show_message(class PROJECT *p, char* message, int priority);
+extern void cleanup_messages();
 
 // the __attribute((format...)) tags are GCC extensions that let the compiler
 // do like-checking on printf-like arguments
