@@ -23,10 +23,11 @@
 
 #ifdef _WIN32
 #include "boinc_win.h"
+#else
+#include "config.h"
 #endif
 
 #ifndef _WIN32
-#include "config.h"
 #include <cassert>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -58,6 +59,7 @@ bool CLIENT_STATE::start_new_file_xfer(PERS_FILE_XFER& pfx) {
     int ntotal=0, nproj=0;
 
     if (network_suspended) return false;
+    if (file_xfers_suspended) return false;
 
 
     // limit the number of file transfers per project
@@ -362,4 +364,3 @@ void CLIENT_STATE::check_file_existence() {
     }
 }
 
-const char *BOINC_RCSID_66410b3cab = "$Id: cs_files.cpp 19106 2009-09-18 20:55:03Z romw $";
