@@ -19,12 +19,15 @@
 // when to compute, how much disk to use, etc.
 //
 
+#include "cpp.h"
+
 #ifdef _WIN32
 #include "boinc_win.h"
+#else
+#include "config.h"
 #endif
 
 #ifndef _WIN32
-#include "config.h"
 #if HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
@@ -99,7 +102,7 @@ int CLIENT_STATE::check_suspend_processing() {
         return SUSPEND_REASON_INITIAL_DELAY;
     }
 
-    switch(run_mode.get_current()) {
+    switch (run_mode.get_current()) {
     case RUN_MODE_ALWAYS: break;
     case RUN_MODE_NEVER:
         return SUSPEND_REASON_USER_REQ;
@@ -125,9 +128,12 @@ int CLIENT_STATE::check_suspend_processing() {
                 return SUSPEND_REASON_NO_RECENT_INPUT;
             }
         }
-        if (active_tasks.exclusive_app_running) {
+        if (exclusive_app_running) {
             return SUSPEND_REASON_EXCLUSIVE_APP_RUNNING;
         }
+        if (global_prefs.suspend_cpu_usage && non_boinc_cpu_usage*100 > global_prefs.suspend_cpu_usage) {
+            return SUSPEND_REASON_CPU_USAGE;
+        }
     }
 
     if (global_prefs.cpu_usage_limit < 99) {        // round-off?
@@ -137,68 +143,83 @@ int CLIENT_STATE::check_suspend_processing() {
         if (diff >= POLL_INTERVAL/2. && diff < POLL_INTERVAL*10.) {
             debt += diff*global_prefs.cpu_usage_limit/100;
             if (debt < 0) {
-                return SUSPEND_REASON_CPU_USAGE_LIMIT;
+                return SUSPEND_REASON_CPU_THROTTLE;
             } else {
                 debt -= diff;
             }
         }
     }
 
+    bool old_gpu_suspended = gpu_suspended;
+    gpu_suspended = false;
+    switch (gpu_mode.get_current()) {
+    case RUN_MODE_ALWAYS:
+        break;
+    case RUN_MODE_NEVER:
+        gpu_suspended = true;
+        break;
+    default:
+        if (exclusive_gpu_app_running) {
+            gpu_suspended = true;
+            break;
+        }
+        if (user_active && !global_prefs.run_gpu_if_user_active) {
+            gpu_suspended = true;
+            break;
+        }
+    }
+
+    if (log_flags.cpu_sched) {
+        if (old_gpu_suspended && !gpu_suspended) {
+            msg_printf(NULL, MSG_INFO, "[cpu_sched] resuming GPU activity");
+        } else if (!old_gpu_suspended && gpu_suspended) {
+            msg_printf(NULL, MSG_INFO, "[cpu_sched] suspending GPU activity");
+        }
+    }
+
     return 0;
 }
 
-static string reason_string(int reason) {
-    string s_reason;
-    if (reason & SUSPEND_REASON_BATTERIES) {
-        s_reason += " - on batteries";
+const char* CLIENT_STATE::suspend_reason_string(int reason) {
+    switch (reason) {
+    case SUSPEND_REASON_BATTERIES: return "on batteries";
+    case SUSPEND_REASON_USER_ACTIVE: return "user is active";
+    case SUSPEND_REASON_USER_REQ: return "user request";
+    case SUSPEND_REASON_TIME_OF_DAY: return "time of day";
+    case SUSPEND_REASON_BENCHMARKS: return "running CPU benchmarks";
+    case SUSPEND_REASON_DISK_SIZE: return "out of disk space - change global prefs";
+    case SUSPEND_REASON_NO_RECENT_INPUT: return "no recent user activity";
+    case SUSPEND_REASON_INITIAL_DELAY: return "initial delay";
+    case SUSPEND_REASON_EXCLUSIVE_APP_RUNNING: return "an exclusive app is running";
+    case SUSPEND_REASON_CPU_USAGE: return "CPU usage is too high";
+    case SUSPEND_REASON_NETWORK_QUOTA_EXCEEDED: return "network bandwidth limit exceeded";
     }
-    if (reason & SUSPEND_REASON_USER_ACTIVE) {
-        s_reason += " - user is active";
-    }
-    if (reason & SUSPEND_REASON_USER_REQ) {
-        s_reason += " - user request";
-    }
-    if (reason & SUSPEND_REASON_TIME_OF_DAY) {
-        s_reason += " - time of day";
-    }
-    if (reason & SUSPEND_REASON_BENCHMARKS) {
-        s_reason += " - running CPU benchmarks";
-    }
-    if (reason & SUSPEND_REASON_DISK_SIZE) {
-        s_reason += " - out of disk space - change global prefs";
-    }
-    if (reason & SUSPEND_REASON_NO_RECENT_INPUT) {
-        s_reason += " - no recent user activity";
-    }
-    if (reason & SUSPEND_REASON_INITIAL_DELAY) {
-        s_reason += " - initial delay";
-    }
-    if (reason & SUSPEND_REASON_EXCLUSIVE_APP_RUNNING) {
-        s_reason += " - an exclusive app is running";
-    }
-    return s_reason;
+    return "unknown reason";
 }
 
 void print_suspend_tasks_message(int reason) {
-    string s_reason = "Suspending computation" + reason_string(reason);
-    msg_printf(NULL, MSG_INFO, s_reason.c_str());
+    char buf[256];
+    sprintf(buf,
+        "Suspending computation - %s",
+        gstate.suspend_reason_string(reason)
+    );
+    msg_printf(NULL, MSG_INFO, buf);
 }
 
 int CLIENT_STATE::suspend_tasks(int reason) {
-    if (reason == SUSPEND_REASON_CPU_USAGE_LIMIT) {
+    if (reason == SUSPEND_REASON_CPU_THROTTLE) {
         if (log_flags.cpu_sched) {
             msg_printf(NULL, MSG_INFO, "[cpu_sched] Suspending - CPU throttle");
         }
-        active_tasks.suspend_all(true);
     } else {
         print_suspend_tasks_message(reason);
-        active_tasks.suspend_all(false);
     }
+    active_tasks.suspend_all(reason);
     return 0;
 }
 
 int CLIENT_STATE::resume_tasks(int reason) {
-    if (reason == SUSPEND_REASON_CPU_USAGE_LIMIT) {
+    if (reason == SUSPEND_REASON_CPU_THROTTLE) {
         if (log_flags.cpu_sched) {
             msg_printf(NULL, MSG_INFO, "[cpu_sched] Resuming - CPU throttle");
         }
@@ -211,39 +232,64 @@ int CLIENT_STATE::resume_tasks(int reason) {
     return 0;
 }
 
-int CLIENT_STATE::check_suspend_network() {
+// Check whether to set network_suspended and file_xfers_suspended.
+//
+void CLIENT_STATE::check_suspend_network() {
+    network_suspended = false;
+    file_xfers_suspended = false;
+    network_suspend_reason = 0;
+
     // no network traffic if we're allowing unsigned apps
     //
-    if (unsigned_apps_ok) return SUSPEND_REASON_USER_REQ;
+    if (unsigned_apps_ok) {
+        network_suspended = true;
+        file_xfers_suspended = true;
+        network_suspend_reason = SUSPEND_REASON_USER_REQ;
+        return;
+    }
+
+    // was there a recent GUI RPC that needs network?
+    //
+    bool recent_rpc = gui_rpcs.recent_rpc_needs_network(
+        ALLOW_NETWORK_IF_RECENT_RPC_PERIOD
+    );
 
     switch(network_mode.get_current()) {
-    case RUN_MODE_ALWAYS: return 0;
+    case RUN_MODE_ALWAYS: 
+        return;
     case RUN_MODE_NEVER:
-        return SUSPEND_REASON_USER_REQ;
+        file_xfers_suspended = true;
+        if (!recent_rpc) network_suspended = true;
+        network_suspend_reason = SUSPEND_REASON_USER_REQ;
     }
+
+    if (global_prefs.daily_xfer_limit_mb && global_prefs.daily_xfer_period_days) {
+        double up, down;
+        daily_xfer_history.totals(
+            global_prefs.daily_xfer_period_days, up, down
+        );
+        if (up+down > global_prefs.daily_xfer_limit_mb*MEGA) {
+            file_xfers_suspended = true;
+            if (!recent_rpc) network_suspended = true;
+            network_suspend_reason = SUSPEND_REASON_NETWORK_QUOTA_EXCEEDED;
+        }
+    }
+
     if (!global_prefs.run_if_user_active && user_active) {
-        return SUSPEND_REASON_USER_ACTIVE;
+        file_xfers_suspended = true;
+        if (!recent_rpc) network_suspended = true;
+        network_suspend_reason = SUSPEND_REASON_USER_ACTIVE;
     }
     if (global_prefs.net_times.suspended()) {
-        return SUSPEND_REASON_TIME_OF_DAY;
+        file_xfers_suspended = true;
+        if (!recent_rpc) network_suspended = true;
+        network_suspend_reason = SUSPEND_REASON_TIME_OF_DAY;
     }
-    if (active_tasks.exclusive_app_running) {
-        return SUSPEND_REASON_EXCLUSIVE_APP_RUNNING;
+    if (exclusive_app_running) {
+        file_xfers_suspended = true;
+        if (!recent_rpc) network_suspended = true;
+        network_suspend_reason = SUSPEND_REASON_EXCLUSIVE_APP_RUNNING;
     }
-    return 0;
-}
-
-int CLIENT_STATE::suspend_network(int reason) {
-    string s_reason;
-    s_reason = "Suspending network activity" + reason_string(reason);
-    msg_printf(NULL, MSG_INFO, s_reason.c_str());
-    pers_file_xfers->suspend();
-    return 0;
-}
-
-int CLIENT_STATE::resume_network() {
-    msg_printf(NULL, MSG_INFO, "Resuming network activity");
-    return 0;
 }
 
 // call this only after parsing global prefs
@@ -395,18 +441,19 @@ void CLIENT_STATE::read_global_prefs() {
         fclose(f);
     }
 
+    msg_printf(NULL, MSG_INFO, "Preferences:");
     msg_printf(NULL, MSG_INFO,
-        "Preferences limit memory usage when active to %.2fMB",
+        "   max memory usage when active: %.2fMB",
         (host_info.m_nbytes*global_prefs.ram_max_used_busy_frac)/MEGA
     );
     msg_printf(NULL, MSG_INFO,
-        "Preferences limit memory usage when idle to %.2fMB",
+        "   max memory usage when idle: %.2fMB",
         (host_info.m_nbytes*global_prefs.ram_max_used_idle_frac)/MEGA
     );
     double x;
     total_disk_usage(x);
     msg_printf(NULL, MSG_INFO,
-        "Preferences limit disk usage to %.2fGB",
+        "   max disk usage: %.2fGB",
         allowed_disk_usage(x)/GIGA
     );
     // max_cpus, bandwidth limits may have changed
@@ -414,11 +461,38 @@ void CLIENT_STATE::read_global_prefs() {
     set_ncpus();
     if (ncpus != host_info.p_ncpus) {
         msg_printf(NULL, MSG_INFO,
-            "Preferences limit # CPUs to %d", ncpus
+            "   max CPUs used: %d", ncpus
+        );
+    }
+    if (!global_prefs.run_if_user_active) {
+        msg_printf(NULL, MSG_INFO, "   don't compute while active");
+    }
+    if (!global_prefs.run_gpu_if_user_active) {
+        msg_printf(NULL, MSG_INFO, "   don't use GPU while active");
+    }
+    if (global_prefs.suspend_cpu_usage) {
+        msg_printf(NULL, MSG_INFO,
+            "   suspend work if non-BOINC CPU load exceeds %.0f %%",
+            global_prefs.suspend_cpu_usage
+        );
+    }
+    if (global_prefs.max_bytes_sec_down) {
+        msg_printf(NULL, MSG_INFO,
+            "   max download rate: %.0f bytes/sec",
+            global_prefs.max_bytes_sec_down
+        );
+    }
+    if (global_prefs.max_bytes_sec_up) {
+        msg_printf(NULL, MSG_INFO,
+            "   max upload rate: %.0f bytes/sec",
+            global_prefs.max_bytes_sec_up
         );
     }
     file_xfers->set_bandwidth_limits(true);
     file_xfers->set_bandwidth_limits(false);
+    msg_printf(NULL, MSG_INFO,
+        "   (to change preferences, visit the web site of an attached project, or select Preferences in the Manager)"
+    );
     request_schedule_cpus("Prefs update");
     request_work_fetch("Prefs update");
 }
@@ -470,4 +544,3 @@ double CLIENT_STATE::max_available_ram() {
     );
 }
 
-const char *BOINC_RCSID_92ad99cddf = "$Id: cs_prefs.cpp 19316 2009-10-16 19:02:00Z romw $";
