@@ -52,45 +52,48 @@ extern void boinc_version_dir(PROJECT&, VERSION_INFO&, char*);
 extern bool is_version_dir(char*, VERSION_INFO&);
 extern void send_log_after(const char* filename, double t, MIOFILE& mf);
 
+#define ACCT_MGR_LOGIN_FILENAME     "acct_mgr_login.xml"
+#define ACCT_MGR_REPLY_FILENAME     "acct_mgr_reply.xml"
+#define ACCT_MGR_REQUEST_FILENAME   "acct_mgr_request.xml"
+#define ACCT_MGR_URL_FILENAME       "acct_mgr_url.xml"
+#define ALL_PROJECTS_LIST_FILENAME "all_projects_list.xml"
+#define ALL_PROJECTS_LIST_FILENAME_TEMP "all_projects_list_temp.xml"
+#define APP_INFO_FILE_NAME			"app_info.xml"
+#define CA_BUNDLE_FILENAME          "ca-bundle.crt"
+#define CERTIFICATE_DIRECTORY       "certificates"
+#define CLIENT_AUTH_FILENAME        "client_auth.xml"
+#define CONFIG_FILE                 "cc_config.xml"
+#define CPU_BENCHMARKS_FILE_NAME    "cpu_benchmarks"
+#define CREATE_ACCOUNT_FILENAME     "create_account.xml"
+#define DAILY_XFER_HISTORY_FILENAME "daily_xfer_history.xml"
+#define GET_CURRENT_VERSION_FILENAME    "get_current_version.xml"
+#define GET_PROJECT_CONFIG_FILENAME "get_project_config.xml"
+#define GLOBAL_PREFS_FILE_NAME      "global_prefs.xml"
+#define GLOBAL_PREFS_OVERRIDE_FILE  "global_prefs_override.xml"
+#define JOB_LOG_BASE                "job_log_"
+#define LOOKUP_ACCOUNT_FILENAME     "lookup_account.xml"
+#define LOOKUP_WEBSITE_FILENAME     "lookup_website.html"
+#define MASTER_BASE                 "master_"
+#define NOTICES_DIR                 "notices"
+#define PROJECT_INIT_FILENAME       "project_init.xml"
 #define PROJECTS_DIR                "projects"
+#define REMOTEHOST_FILE_NAME        "remote_hosts.cfg"
+#define SCHED_OP_REPLY_BASE         "sched_reply_"
+#define SCHED_OP_REQUEST_BASE       "sched_request_"
+#define SETPROJECTGRP_FILE_NAME     "setprojectgrp"
 #define SLOTS_DIR                   "slots"
-#define SWITCHER_DIR                "switcher"
 #define STATE_FILE_NEXT             "client_state_next.xml"
 #define STATE_FILE_NAME             "client_state.xml"
 #define STATE_FILE_PREV             "client_state_prev.xml"
-#define GLOBAL_PREFS_FILE_NAME      "global_prefs.xml"
-#define GLOBAL_PREFS_OVERRIDE_FILE  "global_prefs_override.xml"
-#define MASTER_BASE                 "master_"
-#define SCHED_OP_REQUEST_BASE       "sched_request_"
-#define SCHED_OP_REPLY_BASE         "sched_reply_"
-#define CONFIG_FILE                 "cc_config.xml"
+#define STDERR_FILE_NAME            "stderr.txt"
+#define STDOUT_FILE_NAME            "stdout.txt"
+#define SWITCHER_DIR                "switcher"
+#define SWITCHER_FILE_NAME          "switcher"
+#define TASK_STATE_FILENAME         "boinc_task_state.xml"
+#define TEMP_ACCT_FILE_NAME         "temp_acct.xml"
 #define TEMP_FILE_NAME              "temp.xml"
 #define TEMP_STATS_FILE_NAME        "temp_stats.xml"
 #define TEMP_TIME_STATS_FILE_NAME   "temp_time_stats.xml"
-#define TEMP_ACCT_FILE_NAME         "temp_acct.xml"
-#define STDERR_FILE_NAME            "stderr.txt"
-#define STDOUT_FILE_NAME            "stdout.txt"
-#define CPU_BENCHMARKS_FILE_NAME    "cpu_benchmarks"
-#define APP_INFO_FILE_NAME			"app_info.xml"
-#define REMOTEHOST_FILE_NAME        "remote_hosts.cfg"
-#define ACCT_MGR_REQUEST_FILENAME   "acct_mgr_request.xml"
-#define ACCT_MGR_REPLY_FILENAME     "acct_mgr_reply.xml"
-#define PROJECT_INIT_FILENAME       "project_init.xml"
-#define ACCT_MGR_URL_FILENAME       "acct_mgr_url.xml"
-#define ACCT_MGR_LOGIN_FILENAME     "acct_mgr_login.xml"
-#define GET_PROJECT_CONFIG_FILENAME "get_project_config.xml"
-#define LOOKUP_ACCOUNT_FILENAME     "lookup_account.xml"
-#define CREATE_ACCOUNT_FILENAME     "create_account.xml"
-#define LOOKUP_WEBSITE_FILENAME     "lookup_website.html"
-#define GET_CURRENT_VERSION_FILENAME    "get_current_version.xml"
-#define ALL_PROJECTS_LIST_FILENAME "all_projects_list.xml"
-#define ALL_PROJECTS_LIST_FILENAME_TEMP "all_projects_list_temp.xml"
-#define SWITCHER_FILE_NAME          "switcher"
-#define SETPROJECTGRP_FILE_NAME     "setprojectgrp"
 #define TIME_STATS_LOG              "time_stats_log"
-#define JOB_LOG_BASE                "job_log_"
-#define CA_BUNDLE_FILENAME          "ca-bundle.crt"
-#define CLIENT_AUTH_FILENAME        "client_auth.xml"
-#define CERTIFICATE_DIRECTORY       "certificates"
-#define TASK_STATE_FILENAME         "boinc_task_state.xml"
+
 #endif
