@@ -15,13 +15,18 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "cpp.h"
+
 #ifdef _WIN32
 #include "boinc_win.h"
 #else
 #include "config.h"
 #endif
 
+#ifndef _WIN32
 #include <cstring>
+#endif
+
 #include "client_state.h"
 #include "filesys.h"
 #include "error_numbers.h"
@@ -75,4 +80,3 @@ bool GUI_HTTP::poll() {
     return true;
 }
 
-const char *BOINC_RCSID_7c374a67d3="$Id: gui_http.cpp 18988 2009-09-02 15:33:06Z romw $";
