@@ -15,15 +15,21 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "cpp.h"
+
+#ifdef __APPLE__
+#include <Carbon/Carbon.h>
+#endif
+
 #ifdef _WIN32
 #include "boinc_win.h"
-
 #else 
-
 #include "config.h"
+#endif
+
+#ifndef _WIN32
 #include <cstdio>
 #include <cstring>
-
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -41,10 +47,6 @@
 #endif
 #endif
 
-#ifdef __APPLE__
-#include <Carbon/Carbon.h>
-#endif
-
 #include "str_util.h"
 #include "str_replace.h"
 #include "parse.h"
@@ -117,5 +119,3 @@ void HOST_INFO::generate_host_cpid() {
 #endif
 }
 
-
-const char *BOINC_RCSID_9275b20aa5 = "$Id: hostinfo_network.cpp 18658 2009-07-22 18:41:02Z davea $";
