@@ -21,12 +21,8 @@
 
 // We use libcurl: http://curl.haxx.se/libcurl
 
-#ifndef _HTTP_
-#define _HTTP_
-
-// SOCKS #defines
-#define SOCKS_VERSION_4             0x04
-#define SOCKS_VERSION_5             0x05
+#ifndef _HTTP_CURL_
+#define _HTTP_CURL_
 
 #include <curl/curl.h>
 
@@ -68,7 +64,7 @@ public:
 
     int content_length;
     double file_offset;
-    int trace_id;
+    unsigned int trace_id;
     char request_header[4096];
 
     FILE* fileIn;
@@ -165,15 +161,6 @@ private:
     );
 };
 
-// global function used by libcurl to write http replies to disk
-//
-size_t libcurl_write(void *ptr, size_t size, size_t nmemb, HTTP_OP* phop);
-size_t libcurl_read( void *ptr, size_t size, size_t nmemb, HTTP_OP* phop);
-curlioerr libcurl_ioctl(CURL *handle, curliocmd cmd, HTTP_OP* phop);
-int libcurl_debugfunction(CURL *handle, curl_infotype type,
-	unsigned char *data, size_t size, HTTP_OP* phop
-);
-
 /// represents a set of HTTP requests in progress
 
 class HTTP_OP_SET {
@@ -195,12 +182,6 @@ public:
 
 };
 
-#define URL_PROTOCOL_UNKNOWN 0
-#define URL_PROTOCOL_HTTP    1
-#define URL_PROTOCOL_HTTPS   2
-#define URL_PROTOCOL_SOCKS   3
-
 extern char* get_user_agent_string();
-extern void parse_url(const char* url, int &protocol, char* host, int &port, char* file);
 
-#endif //__HTTP_H
+#endif //__HTTP_CURL_
