@@ -19,6 +19,8 @@
 
 // This file contains no GUI-related code.
 
+#include "cpp.h"
+
 #ifdef WIN32
 #include "boinc_win.h"
 #include "sysmon_win.h"
@@ -56,6 +58,8 @@ typedef void (CALLBACK* ClientLibraryShutdown)();
 #include "prefs.h"
 #include "filesys.h"
 #include "network.h"
+
+#include "cs_proxy.h"
 #include "client_state.h"
 #include "file_names.h"
 #include "log_flags.h"
@@ -210,6 +214,7 @@ static void init_core_client(int argc, char** argv) {
     setbuf(stdout, 0);
     setbuf(stderr, 0);
 
+    config.clear();
     gstate.parse_cmdline(argc, argv);
 
 #ifdef _WIN32
@@ -229,6 +234,9 @@ static void init_core_client(int argc, char** argv) {
 
     // Initialize the BOINC Diagnostics Framework
     int flags =
+#ifdef _DEBUG
+        BOINC_DIAG_MEMORYLEAKCHECKENABLED |
+#endif
         BOINC_DIAG_DUMPCALLSTACKENABLED |
         BOINC_DIAG_HEAPCHECKENABLED |
         BOINC_DIAG_TRACETOSTDOUT;
@@ -328,84 +336,12 @@ int initialize() {
     return 0;
 }
 
-int boinc_main_loop() {
-    int retval;
-    
-    retval = initialize();
-    if (retval) return retval;
-
-    retval = gstate.init();
-    if (retval) {
-        log_message_error("gstate.init() failed", retval);
-        return retval;
-    }
-
-    log_message_startup("BOINC initialization completed, beginning process execution...");
-
-    // must parse env vars after gstate.init();
-    // otherwise items will get overwritten with state file info
-    //
-    gstate.parse_env_vars();
-
-    if (gstate.projects.size() == 0) {
-        msg_printf(NULL, MSG_INFO,
-            "This computer is not attached to any projects"
-        );
-        msg_printf(NULL, MSG_INFO,
-            "Visit http://boinc.berkeley.edu for instructions"
-        );
-    }
-
-    while (1) {
-        if (!gstate.poll_slow_events()) {
-            gstate.do_io_or_sleep(POLL_INTERVAL);
-        }
-        fflush(stderr);
-        fflush(stdout);
-
-        if (gstate.time_to_exit()) {
-            msg_printf(NULL, MSG_INFO, "Time to exit");
-            break;
-        }
-        if (gstate.requested_exit) {
-            if (gstate.abort_jobs_on_exit) {
-                if (!gstate.in_abort_sequence) {
-                    msg_printf(NULL, MSG_INFO,
-                        "Exit requested; starting abort sequence"
-                    );
-                    gstate.start_abort_sequence();
-                }
-            } else {
-                msg_printf(NULL, MSG_INFO, "Exit requested by user");
-                break;
-            }
-        }
-        if (gstate.in_abort_sequence) {
-            if (gstate.abort_sequence_done()) {
-                msg_printf(NULL, MSG_INFO, "Abort sequence done; exiting");
-                break;
-            }
-        }
-        if (gstate.requested_suspend) {
-            gstate.run_mode.set(RUN_MODE_NEVER, 3600);
-            gstate.network_mode.set(RUN_MODE_NEVER, 3600);
-            gstate.requested_suspend = false;
-        }
-        if (gstate.requested_resume) {
-            gstate.run_mode.set(RUN_MODE_RESTORE, 0);
-            gstate.network_mode.set(RUN_MODE_RESTORE, 0);
-            gstate.requested_resume = false;
-        }
-    }
-
-    return finalize();
-}
-
 int finalize() {
     static bool finalized = false;
     if (finalized) return 0;
     finalized = true;
     gstate.quit_activities();
+    daily_xfer_history.write_state();
 
 #ifdef _WIN32
     if(g_hClientLibraryDll) {
@@ -441,10 +377,90 @@ int finalize() {
 #endif
 
 	curl_cleanup();
+
+    gstate.free_mem();
+
     gstate.cleanup_completed = true;
     return 0;
 }
 
+int boinc_main_loop() {
+    int retval;
+    
+    retval = initialize();
+    if (retval) return retval;
+
+    retval = gstate.init();
+    if (retval) {
+        log_message_error("gstate.init() failed", retval);
+        return retval;
+    }
+
+    // must parse env vars after gstate.init();
+    // otherwise items will get overwritten with state file info
+    //
+    gstate.parse_env_vars();
+
+    // do this after parsing env vars
+    //
+    proxy_info_startup();
+
+    if (gstate.projects.size() == 0) {
+        msg_printf(NULL, MSG_INFO,
+            "This computer is not attached to any projects"
+        );
+        msg_printf(NULL, MSG_INFO,
+            "Visit http://boinc.berkeley.edu for instructions"
+        );
+    }
+
+    log_message_startup("Initialization completed");
+
+    while (1) {
+        if (!gstate.poll_slow_events()) {
+            gstate.do_io_or_sleep(POLL_INTERVAL);
+        }
+        fflush(stderr);
+        fflush(stdout);
+
+        if (gstate.time_to_exit()) {
+            msg_printf(NULL, MSG_INFO, "Time to exit");
+            break;
+        }
+        if (gstate.requested_exit) {
+            if (config.abort_jobs_on_exit) {
+                if (!gstate.in_abort_sequence) {
+                    msg_printf(NULL, MSG_INFO,
+                        "Exit requested; starting abort sequence"
+                    );
+                    gstate.start_abort_sequence();
+                }
+            } else {
+                msg_printf(NULL, MSG_INFO, "Exit requested by user");
+                break;
+            }
+        }
+        if (gstate.in_abort_sequence) {
+            if (gstate.abort_sequence_done()) {
+                msg_printf(NULL, MSG_INFO, "Abort sequence done; exiting");
+                break;
+            }
+        }
+        if (gstate.requested_suspend) {
+            gstate.run_mode.set(RUN_MODE_NEVER, 3600);
+            gstate.network_mode.set(RUN_MODE_NEVER, 3600);
+            gstate.requested_suspend = false;
+        }
+        if (gstate.requested_resume) {
+            gstate.run_mode.set(RUN_MODE_RESTORE, 0);
+            gstate.network_mode.set(RUN_MODE_RESTORE, 0);
+            gstate.requested_resume = false;
+        }
+    }
+
+    return finalize();
+}
+
 int main(int argc, char** argv) {
     int retval = 0;
 
@@ -567,5 +583,3 @@ int main(int argc, char** argv) {
     return retval;
 }
 
-
-const char *BOINC_RCSID_f02264aefe = "$Id: main.cpp 18813 2009-08-04 05:52:04Z charlief $";
