@@ -172,23 +172,33 @@ void CLIENT_STATE::get_workload(vector<IP_RESULT>& ip_results) {
     init_ip_results(work_buf_min(), ncpus, ip_results);
 }
 
+// simulate trying to do an RPC
+// return false if we didn't actually do one
+//
 bool CLIENT_STATE::simulate_rpc(PROJECT* _p) {
     char buf[256];
     SIM_PROJECT* p = (SIM_PROJECT*) _p;
-    static double last_time=0;
+    static double last_time=-1e9;
     vector<IP_RESULT> ip_results;
     int infeasible_count = 0;
 
     double diff = now - last_time;
     if (diff && diff < host_info.connection_interval) {
-        msg_printf(NULL, MSG_INFO, "simulate_rpc: too soon %f < %f", diff, host_info.connection_interval);
+        msg_printf(NULL, MSG_INFO,
+            "simulate_rpc: too soon %f < %f",
+            diff, host_info.connection_interval
+        );
         return false;
     }
     last_time = now;
 
-    sprintf(buf, "RPC to %s; asking for %f<br>", p->project_name, cpu_work_fetch.req_secs);
+    sprintf(buf, "RPC to %s; asking for %f/%.2f<br>",
+        p->project_name, cpu_work_fetch.req_secs, cpu_work_fetch.req_instances
+    );
     html_msg += buf;
 
+    msg_printf(0, MSG_INFO, buf);
+
     handle_completed_results();
 
     if (server_uses_workload) {
@@ -197,7 +207,8 @@ bool CLIENT_STATE::simulate_rpc(PROJECT* _p) {
 
     bool sent_something = false;
     double work_left = cpu_work_fetch.req_secs;
-    while (work_left > 0) {
+    double instances_needed = cpu_work_fetch.req_instances;
+    while (work_left > 0 || instances_needed>0) {
         RESULT* rp = new RESULT;
         WORKUNIT* wup = new WORKUNIT;
         make_job(p, wup, rp);
@@ -224,15 +235,17 @@ bool CLIENT_STATE::simulate_rpc(PROJECT* _p) {
         );
         html_msg += buf;
         work_left -= p->duration_correction_factor*wup->rsc_fpops_est/host_info.p_fpops;
+        instances_needed -= 1;
     }
 
     if (cpu_work_fetch.req_secs > 0 && !sent_something) {
         p->backoff();
-    } else {
-        p->nrpc_failures = 0;
     }
-    request_schedule_cpus("simulate_rpc");
-    request_work_fetch("simulate_rpc");
+    p->nrpc_failures = 0;
+    if (sent_something) {
+        request_schedule_cpus("simulate_rpc");
+        request_work_fetch("simulate_rpc");
+    }
     return true;
 }
 
@@ -246,23 +259,62 @@ void SIM_PROJECT::backoff() {
 
 bool CLIENT_STATE::scheduler_rpc_poll() {
     PROJECT *p;
+    bool action = false;
+    static double last_time=0;
+    static double last_work_fetch_time = 0;
+    double elapsed_time;
+
+    // check only every 5 sec
+    //
+    if (now - last_time < SCHEDULER_RPC_POLL_PERIOD) {
+        msg_printf(NULL, MSG_INFO, "RPC poll: not time %f - %f < %f",
+            now, last_time, SCHEDULER_RPC_POLL_PERIOD
+        );
+        return false;
+    }
+    last_time = now;
 
     msg_printf(NULL, MSG_INFO, "RPC poll start");
-    p = next_project_sched_rpc_pending();
-    if (p) {
-        return simulate_rpc(p);
-    }
+    while (1) {
+        p = next_project_sched_rpc_pending();
+        if (p) {
+            work_fetch.compute_work_request(p);
+            action = simulate_rpc(p);
+            break;
+        }
     
-    p = find_project_with_overdue_results();
-    if (p) {
-        return simulate_rpc(p);
+        p = find_project_with_overdue_results();
+        if (p) {
+            work_fetch.compute_work_request(p);
+            action = simulate_rpc(p);
+            break;
+        }
+
+        // should we check work fetch?  Do this at most once/minute
+
+        if (must_check_work_fetch) {
+            last_work_fetch_time = 0;
+        }
+        elapsed_time = now - last_work_fetch_time;
+        if (elapsed_time < WORK_FETCH_PERIOD) {
+            return false;
+        }
+        must_check_work_fetch = false;
+        last_work_fetch_time = now;
+
+        p = work_fetch.choose_project();
+        if (p) {
+            action = simulate_rpc(p);
+            break;
+        }
+        break;
     }
-    p = work_fetch.choose_project();
-    if (p) {
-        return simulate_rpc(p);
+    if (action) {
+        msg_printf(p, MSG_INFO, "RPC poll: did an RPC");
+    } else {
+        msg_printf(0, MSG_INFO, "RPC poll: didn't do an RPC");
     }
-    msg_printf(NULL, MSG_INFO, "RPC poll: nothing to do");
-    return false;
+    return action;
 }
 
 bool ACTIVE_TASK_SET::poll() {
@@ -280,9 +332,9 @@ bool ACTIVE_TASK_SET::poll() {
     for (i=0; i<gstate.projects.size(); i++) {
         p = (SIM_PROJECT*) gstate.projects[i];
         p->idle = true;
-        sprintf(buf, "%s STD: %f min RPC<br>",
-            p->project_name, p->short_term_debt,
-            time_to_string(p->min_rpc_time)
+        sprintf(buf, "%s STD: %f LTD %f<br>",
+            p->project_name, p->cpu_pwf.short_term_debt,
+            p->pwf.overall_debt
         );
         gstate.html_msg += buf;
     }
@@ -488,6 +540,51 @@ char* colors[] = {
 
 static int outfile_num=0;
 
+bool uses_coproc(RESULT* rp, COPROC* cp) {
+    return false;
+}
+
+bool using_instance(RESULT*, int) {
+    return false;
+}
+
+void gpu_header() {
+    for (unsigned int i=0; i<gstate.host_info.coprocs.coprocs.size(); i++) {
+        COPROC* cp = gstate.host_info.coprocs.coprocs[i];
+        for (int j=0; j<cp->count; j++) {
+            fprintf(gstate.html_out, "<th>%s %d</th>", cp->type, j);
+        }
+    }
+}
+void gpu_off() {
+    for (unsigned int i=0; i<gstate.host_info.coprocs.coprocs.size(); i++) {
+        COPROC* cp = gstate.host_info.coprocs.coprocs[i];
+        for (int j=0; j<cp->count; j++) {
+            fprintf(gstate.html_out, "<td bgcolor=#aaaaaa>OFF</td>");
+        }
+    }
+}
+void gpu_on() {
+    for (unsigned int i=0; i<gstate.host_info.coprocs.coprocs.size(); i++) {
+        COPROC* cp = gstate.host_info.coprocs.coprocs[i];
+        for (int j=0; j<cp->count; j++) {
+            for (unsigned int k=0; k<gstate.active_tasks.active_tasks.size(); k++) {
+                ACTIVE_TASK* atp = gstate.active_tasks.active_tasks[k];
+                RESULT* rp = atp->result;
+                if (!uses_coproc(rp, cp)) continue;
+                if (atp->task_state() != PROCESS_EXECUTING) continue;
+                if (!using_instance(rp, j)) continue;
+                SIM_PROJECT* p = (SIM_PROJECT*)rp->project;
+                fprintf(gstate.html_out, "<td bgcolor=%s>%s%s: %.2f</td>",
+                    colors[p->index],
+                    atp->result->rr_sim_misses_deadline?"*":"",
+                    atp->result->name, atp->cpu_time_left
+                );
+            }
+        }
+    }
+}
+
 void CLIENT_STATE::html_start(bool show_prev) {
     char buf[256];
 
@@ -510,6 +607,7 @@ void CLIENT_STATE::html_start(bool show_prev) {
             "<th>CPU %d<br><font size=-2>Job name and estimated time left<br>color denotes project<br>* means EDF mode</font></th>", i
         );
     }
+    gpu_header();
     fprintf(html_out, "<th>Notes</th></tr>\n");
 }
 
@@ -522,6 +620,7 @@ void CLIENT_STATE::html_rec() {
         for (int j=0; j<ncpus; j++) {
             fprintf(html_out, "<td bgcolor=#aaaaaa>OFF</td>");
         }
+        gpu_off();
     } else {
         int n=0;
         for (unsigned int i=0; i<active_tasks.active_tasks.size(); i++) {
@@ -541,7 +640,9 @@ void CLIENT_STATE::html_rec() {
             n++;
         }
     }
-    fprintf(html_out, "<td><font size=-2>%s</font></td></tr>\n", html_msg.c_str());
+    fprintf(html_out,
+        "<td><font size=-2>%s</font></td></tr>\n", html_msg.c_str()
+    );
     html_msg = "";
 
     if (++line_num == line_limit) {
@@ -579,11 +680,16 @@ void CLIENT_STATE::html_end(bool show_next) {
 
 void CLIENT_STATE::simulate() {
     bool action;
-    now = 0;
+    double start = START_TIME;
+    now = start;
     html_start(false);
+    msg_printf(0, MSG_INFO,
+        "starting simultion. delta %f duration %f", delta, duration
+    );
     while (1) {
         running = host_info.available.sample(now);
         while (1) {
+            msg_printf(0, MSG_INFO, "polling");
             action = active_tasks.poll();
             if (running) {
                 action |= handle_finished_apps();
@@ -591,11 +697,19 @@ void CLIENT_STATE::simulate() {
                 action |= enforce_schedule();
                 action |= scheduler_rpc_poll();
             }
+            msg_printf(0, MSG_INFO, action?"did action":"did no action");
             if (!action) break;
         }
         now += delta;
+        msg_printf(0, MSG_INFO, "took time step");
+        for (unsigned int i=0; i<active_tasks.active_tasks.size(); i++) {
+            ACTIVE_TASK* atp = active_tasks.active_tasks[i];
+            if (atp->task_state() == PROCESS_EXECUTING) {
+                atp->elapsed_time += delta;
+            }
+        }
         html_rec();
-        if (now > duration) break;
+        if (now > start + duration) break;
     }
     html_end(false);
 }
@@ -718,18 +832,22 @@ int main(int argc, char** argv) {
         total_results.divide((int)(dirs.size()));
         total_results.print(stdout, "Total");
     } else {
+        msg_printf(0, MSG_INFO, "SIMULATION START");
         read_config_file(true);
+        config.show();
+
         int retval;
         bool flag;
 
-        retval = gstate.parse_projects(PROJECTS_FILE);
-        if (retval) parse_error(PROJECTS_FILE, retval);
         retval = gstate.parse_host(HOST_FILE);
         if (retval) parse_error(HOST_FILE, retval);
+        retval = gstate.parse_projects(PROJECTS_FILE);
+        if (retval) parse_error(PROJECTS_FILE, retval);
         retval = gstate.global_prefs.parse_file(PREFS_FILE, "", flag);
         if (retval) parse_error(PREFS_FILE, retval);
 
         gstate.set_ncpus();
+        work_fetch.init();
         gstate.request_work_fetch("init");
         gstate.simulate();
 
