@@ -15,37 +15,38 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "cpp.h"
+
 #ifdef _WIN32
 #include "boinc_win.h"
+#else
+#include "config.h"
 #endif
 
 #ifndef _WIN32
-#include "config.h"
 #include <cstdio>
 #include <ctime>
 #include <cmath>
-#endif
-
+#include <cstring>
 #ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
+#endif
 
-#include <cstring>
 #include "parse.h"
 #include "util.h"
 #include "filesys.h"
 #include "error_numbers.h"
 #include "client_msgs.h"
 #include "file_names.h"
+#include "network.h"
+#include "log_flags.h"
+#include "time_stats.h"
 #ifdef SIM
 #include "sim.h"
 #else
 #include "client_state.h"
 #endif
-#include "network.h"
-#include "log_flags.h"
-
-#include "time_stats.h"
 
 #define CONNECTED_STATE_UNINITIALIZED   -1
 #define CONNECTED_STATE_NOT_CONNECTED   0
@@ -55,13 +56,11 @@
 #ifndef SIM
 #ifdef _WIN32
 #include <sensapi.h>
-
 int get_connected_state() {
     DWORD flags;
     return IsNetworkAlive(&flags)?CONNECTED_STATE_CONNECTED:CONNECTED_STATE_NOT_CONNECTED;
 }
 #else
-
 // anyone know how to see if this host has physical network connection?
 //
 int get_connected_state() {
@@ -152,7 +151,7 @@ void TIME_STATS::get_log_after(double t, MIOFILE& mf) {
 void TIME_STATS::update(int suspend_reason) {
     double dt, w1, w2;
 
-    bool is_active = !(suspend_reason & ~SUSPEND_REASON_CPU_USAGE_LIMIT);
+    bool is_active = !(suspend_reason & ~SUSPEND_REASON_CPU_THROTTLE);
     if (last_update == 0) {
         // this is the first time this client has executed.
         // Assume that everything is active
@@ -359,4 +358,3 @@ void TIME_STATS::log_append_net(int new_state) {
     }
 }
 
-const char *BOINC_RCSID_472504d8c2 = "$Id: time_stats.cpp 19066 2009-09-17 15:12:30Z romw $";
