@@ -20,12 +20,15 @@
 // Modified a little to work with BOINC
 //
 
+#include "cpp.h"
+
 #ifdef _WIN32
 #include "boinc_win.h"
+#else
+#include "config.h"
 #endif
 
 #ifndef _WIN32
-#include "config.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -278,4 +281,3 @@ int whetstone(double& flops, double& cpu_time, double min_cpu_time) {
     return 0;
 }
 
-const char *BOINC_RCSID_595304be61 = "$Id: whetstone.cpp 17954 2009-04-30 21:48:20Z davea $";
