@@ -95,12 +95,15 @@ CDlgAdvPreferences::~CDlgAdvPreferences() {
 void CDlgAdvPreferences::SetValidators() {
 	//proc page
 	m_txtProcIdleFor->SetValidator(wxTextValidator(wxFILTER_NUMERIC));
+	m_txtMaxLoad->SetValidator(wxTextValidator(wxFILTER_NUMERIC));
 	m_txtProcSwitchEvery->SetValidator(wxTextValidator(wxFILTER_NUMERIC));
 	m_txtProcUseProcessors->SetValidator(wxTextValidator(wxFILTER_NUMERIC));
 	m_txtProcUseCPUTime->SetValidator(wxTextValidator(wxFILTER_NUMERIC));
 	//net page
 	m_txtNetConnectInterval->SetValidator(wxTextValidator(wxFILTER_NUMERIC));
 	m_txtNetDownloadRate->SetValidator(wxTextValidator(wxFILTER_NUMERIC));
+	m_txt_daily_xfer_limit_mb->SetValidator(wxTextValidator(wxFILTER_NUMERIC));
+	m_txt_daily_xfer_period_days->SetValidator(wxTextValidator(wxFILTER_NUMERIC));
 	m_txtNetUploadRate->SetValidator(wxTextValidator(wxFILTER_NUMERIC));
 	m_txtNetAdditionalDays->SetValidator(wxTextValidator(wxFILTER_NUMERIC));
 	//disk and memory page
@@ -133,7 +136,7 @@ void CDlgAdvPreferences::SetSpecialTooltips() {
 	m_txtNetSunday->SetToolTip(TXT_NET_TIME_TOOLTIP);
 }
 
-/* saves selected tab page and dialog size*/
+/* saves dialog siz e*/
 bool CDlgAdvPreferences::SaveState() {
     wxString        strBaseConfigLocation = wxString(wxT("/DlgAdvPreferences/"));
     wxConfigBase*   pConfig = wxConfigBase::Get(FALSE);
@@ -143,16 +146,14 @@ bool CDlgAdvPreferences::SaveState() {
 
 	pConfig->SetPath(strBaseConfigLocation);
 	pConfig->Write(wxT("CurrentPage"),m_Notebook->GetSelection());
-	pConfig->Write(wxT("Width"),this->GetSize().GetWidth());
-	pConfig->Write(wxT("Height"),this->GetSize().GetHeight());
 	return true;
 }
 
-/* restores former selected tab page and dialog size*/
+/* restores former dialog size */
 bool CDlgAdvPreferences::RestoreState() {
     wxString        strBaseConfigLocation = wxString(wxT("/DlgAdvPreferences/"));
     wxConfigBase*   pConfig = wxConfigBase::Get(FALSE);
-	int				p,w,h;
+	int				p;
 
 	wxASSERT(pConfig);
 
@@ -162,9 +163,6 @@ bool CDlgAdvPreferences::RestoreState() {
 
 	pConfig->Read(wxT("CurrentPage"), &p,0);
 	m_Notebook->SetSelection(p);	
-	pConfig->Read(wxT("Width"), &w,-1);
-	pConfig->Read(wxT("Height"), &h,-1);
-	this->SetSize(w,h);	
 
 	return true;
 }
@@ -229,7 +227,11 @@ void CDlgAdvPreferences::ReadPreferenceSettings() {
 	// idle for X minutes
 	buffer.Printf(wxT("%.2f"),prefs.idle_time_to_run);
 	*m_txtProcIdleFor << buffer;
-	// siwtch every X minutes
+
+	buffer.Printf(wxT("%.0f"), prefs.suspend_cpu_usage);
+	*m_txtMaxLoad << buffer;
+
+	// switch every X minutes
 	buffer.Printf(wxT("%.2f"),prefs.cpu_scheduling_period_minutes);
 	*m_txtProcSwitchEvery << buffer;
 	// max cpus
@@ -264,6 +266,12 @@ void CDlgAdvPreferences::ReadPreferenceSettings() {
 	// upload rate
 	buffer.Printf(wxT("%.2f"),prefs.max_bytes_sec_up / 1024);
 	*m_txtNetUploadRate << buffer;
+
+	buffer.Printf(wxT("%.2f"),prefs.daily_xfer_limit_mb);
+	*m_txt_daily_xfer_limit_mb << buffer;
+	buffer.Printf(wxT("%d"),prefs.daily_xfer_period_days );
+	*m_txt_daily_xfer_period_days << buffer;
+
 	//
 	buffer.Printf(wxT("%.2f"),prefs.work_buf_additional_days);
 	*m_txtNetAdditionalDays << buffer;
@@ -331,6 +339,11 @@ bool CDlgAdvPreferences::SavePreferencesSettings() {
 		prefs.idle_time_to_run=td;
 		mask.idle_time_to_run=true;
 	}
+
+    m_txtMaxLoad->GetValue().ToDouble(&td);
+    prefs.suspend_cpu_usage=td;
+    mask.suspend_cpu_usage=true;
+
 	//
 	prefs.cpu_times.start_hour=TimeStringToDouble(m_txtProcEveryDayStart->GetValue());
 	mask.start_hour = true;        
@@ -379,6 +392,13 @@ bool CDlgAdvPreferences::SavePreferencesSettings() {
 	td = td * 1024;
 	prefs.max_bytes_sec_up=td;
 	mask.max_bytes_sec_up=true;
+
+    m_txt_daily_xfer_limit_mb->GetValue().ToDouble(&td);
+	prefs.daily_xfer_limit_mb=td;
+	mask.daily_xfer_limit_mb=true;
+    m_txt_daily_xfer_period_days->GetValue().ToDouble(&td);
+	prefs.daily_xfer_period_days=(int)td;
+	mask.daily_xfer_period_days=true;
 	//
 	prefs.dont_verify_images=m_chkNetSkipImageVerification->GetValue();
 	mask.dont_verify_images=true;
@@ -489,6 +509,11 @@ bool CDlgAdvPreferences::ValidateInput() {
 			return false;
 		}
 	}
+    buffer = m_txtMaxLoad->GetValue();
+    if(!IsValidFloatValue(buffer)) {
+        ShowErrorMessage(invMsgFloat, m_txtMaxLoad);
+        return false;
+    }
 	
 	buffer = m_txtProcEveryDayStart->GetValue();
 	if(!IsValidTimeValue(buffer)) {
