@@ -1,21 +1,19 @@
-// Berkeley Open Infrastructure for Network Computing
+// This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2005 University of California
+// Copyright (C) 2008 University of California
 //
-// This is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public
-// License as published by the Free Software Foundation;
-// either version 2.1 of the License, or (at your option) any later version.
+// BOINC is free software; you can redistribute it and/or modify it
+// under the terms of the GNU Lesser General Public License
+// as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
-// This software is distributed in the hope that it will be useful,
+// BOINC is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Lesser General Public License for more details.
 //
-// To view the GNU Lesser General Public License visit
-// http://www.gnu.org/copyleft/lesser.html
-// or write to the Free Software Foundation, Inc.,
-// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+// You should have received a copy of the GNU Lesser General Public License
+// along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 //
 #ifndef _WIZ_PROJECTINFOPAGE_H_
 #define _WIZ_PROJECTINFOPAGE_H_
@@ -56,8 +54,11 @@ public:
     /// wxEVT_WIZARD_PAGE_CHANGING event handler for ID_PROJECTINFOPAGE
     void OnPageChanging( wxWizardExEvent& event );
 
-    /// wxEVT_PROJECTLISTCTRL_SELECTION_CHANGED event handler for ID_PROJECTSELECTIONCTRL
-    void OnProjectSelectionChanged( ProjectListCtrlEvent& event );
+    /// wxEVT_PROJECTLIST_ITEM_CHANGE event handler for ID_PROJECTSELECTIONCTRL
+    void OnProjectItemChange( ProjectListCtrlEvent& event );
+
+    /// wxEVT_PROJECTLIST_ITEM_DISPLAY event handler for ID_PROJECTSELECTIONCTRL
+    void OnProjectItemDisplay( ProjectListCtrlEvent& event );
 
     /// wxEVT_WIZARD_CANCEL event handler for ID_PROJECTINFOPAGE
     void OnCancel( wxWizardExEvent& event );
@@ -75,6 +76,9 @@ public:
     wxString GetProjectURL() const { return m_strProjectURL ; }
     void SetProjectURL(wxString value) { m_strProjectURL = value ; }
 
+    bool GetProjectSupported() const { return m_bProjectSupported ; }
+    void SetProjectSupported(bool value) { m_bProjectSupported = value ; }
+
     /// Retrieves bitmap resources
     wxBitmap GetBitmapResource( const wxString& name );
 
@@ -91,10 +95,10 @@ public:
     CProjectListCtrl* m_pProjectListCtrl;
     wxStaticText* m_pProjectUrlStaticCtrl;
     wxTextCtrl* m_pProjectUrlCtrl;
-    wxString m_strProjectURL;
 ////@end CProjectInfoPage member variables
-    bool                bProjectListPopulated;
-    ALL_PROJECTS_LIST   pl;
+    wxString m_strProjectURL;
+    bool m_bProjectSupported;
+    bool m_bProjectListPopulated;
 };
 
 #endif // _WIZ_PROJECTINFOPAGE_H_
