@@ -116,8 +116,7 @@ bool CProjectProcessingPage::Create( CBOINCBaseWizard* parent )
     m_iCurrentState = ATTACHPROJECT_INIT;
  
 ////@begin CProjectProcessingPage creation
-    wxBitmap wizardBitmap(wxNullBitmap);
-    wxWizardPageEx::Create( parent, ID_PROJECTPROCESSINGPAGE, wizardBitmap );
+    wxWizardPageEx::Create( parent, ID_PROJECTPROCESSINGPAGE );
 
     CreateControls();
     GetSizer()->Fit(this);
@@ -403,6 +402,7 @@ void CProjectProcessingPage::OnStateChange( CProjectProcessingPageEvent& WXUNUSE
                 ai->email_addr = (const char*)pWAP->m_AccountInfoPage->GetAccountEmailAddress().mb_str();
                 ai->passwd = (const char*)pWAP->m_AccountInfoPage->GetAccountPassword().mb_str();
                 ai->user_name = (const char*)::wxGetUserName().mb_str();
+                ai->team_name = pWAP->team_name;
                 if (ai->user_name.empty()) {
                     ai->user_name = (const char*)::wxGetUserId().mb_str();
                 }
