@@ -118,10 +118,41 @@ CViewMessages::CViewMessages(wxNotebook* pNotebook) :
     m_pListPane->InsertColumn(COLUMN_TIME, _("Time"), wxLIST_FORMAT_LEFT, 145);
     m_pListPane->InsertColumn(COLUMN_MESSAGE, _("Message"), wxLIST_FORMAT_LEFT, 550);
 
-    m_pMessageInfoAttr = new wxListItemAttr(*wxBLACK, *wxWHITE, wxNullFont);
-    m_pMessageErrorAttr = new wxListItemAttr(*wxRED, *wxWHITE, wxNullFont);
-    m_pMessageInfoGrayAttr = new wxListItemAttr(*wxBLACK, wxColour(240, 240, 240), wxNullFont);
-    m_pMessageErrorGrayAttr = new wxListItemAttr(*wxRED, wxColour(240, 240, 240), wxNullFont);
+#if BASEVIEW_STRIPES    
+    m_pMessageInfoAttr = new wxListItemAttr(
+        m_pWhiteBackgroundAttr->GetTextColour(), 
+        m_pWhiteBackgroundAttr->GetBackgroundColour(), 
+        wxNullFont
+    );
+    m_pMessageErrorAttr = new wxListItemAttr(
+        *wxRED, 
+        m_pWhiteBackgroundAttr->GetBackgroundColour(), 
+        wxNullFont
+    );
+    m_pMessageInfoGrayAttr = new wxListItemAttr(
+        m_pGrayBackgroundAttr->GetTextColour(), 
+        m_pGrayBackgroundAttr->GetBackgroundColour(), 
+        wxNullFont
+    );
+    m_pMessageErrorGrayAttr = new wxListItemAttr(
+        *wxRED, 
+        m_pGrayBackgroundAttr->GetBackgroundColour(), 
+        wxNullFont
+    );
+#else
+    m_pMessageInfoAttr = new wxListItemAttr(
+        wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT),
+        wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW),
+        wxNullFont
+    );
+    m_pMessageErrorAttr = new wxListItemAttr(
+        *wxRED, 
+        wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW),
+        wxNullFont
+    );
+    m_pMessageInfoGrayAttr = new wxListItemAttr(*m_pMessageInfoAttr);
+    m_pMessageErrorGrayAttr = new wxListItemAttr(*m_pMessageErrorAttr);
+#endif
 
     UpdateSelection();
 }
@@ -370,9 +401,9 @@ void CViewMessages::OnListRender (wxTimerEvent& event) {
             if (was_connected != isConnected) {
                 was_connected = isConnected;
                 if (isConnected) {
-                    m_pMessageInfoAttr->SetTextColour(*wxBLACK);
+                    m_pMessageInfoAttr->SetTextColour(m_pWhiteBackgroundAttr->GetTextColour());
                     m_pMessageErrorAttr->SetTextColour(*wxRED);
-                    m_pMessageInfoGrayAttr->SetTextColour(*wxBLACK);
+                    m_pMessageInfoGrayAttr->SetTextColour(m_pGrayBackgroundAttr->GetTextColour());
                     m_pMessageErrorGrayAttr->SetTextColour(*wxRED);
                 } else {
                     wxColourDatabase colorBase;
@@ -617,4 +648,4 @@ bool CViewMessages::CloseClipboard() {
 #endif
 
 
-const char *BOINC_RCSID_0be7149475 = "$Id: ViewMessages.cpp 18928 2009-08-27 21:04:52Z charlief $";
+const char *BOINC_RCSID_0be7149475 = "$Id: ViewMessages.cpp 20952 2010-03-18 21:54:20Z charlief $";
