@@ -1,21 +1,19 @@
-// Berkeley Open Infrastructure for Network Computing
+// This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2005 University of California
+// Copyright (C) 2008 University of California
 //
-// This is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public
-// License as published by the Free Software Foundation;
-// either version 2.1 of the License, or (at your option) any later version.
+// BOINC is free software; you can redistribute it and/or modify it
+// under the terms of the GNU Lesser General Public License
+// as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
-// This software is distributed in the hope that it will be useful,
+// BOINC is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Lesser General Public License for more details.
 //
-// To view the GNU Lesser General Public License visit
-// http://www.gnu.org/copyleft/lesser.html
-// or write to the Free Software Foundation, Inc.,
-// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+// You should have received a copy of the GNU Lesser General Public License
+// along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
 #if defined(__GNUG__) && !defined(__APPLE__)
 #pragma implementation "ViewProjectsGrid.h"
@@ -120,8 +118,7 @@ CViewProjectsGrid::CViewProjectsGrid(wxNotebook* pNotebook) :
 
 	pItem = new CTaskItem(
         _("Update"),
-        _("Report all completed tasks, get latest credit, "
-          "get latest preferences, and possibly get more tasks."),
+        _("Report all completed tasks, get latest credit, get latest preferences, and possibly get more tasks."),
         ID_TASK_PROJECT_UPDATE
     );
     pGroup->m_Tasks.push_back( pItem );
@@ -142,19 +139,14 @@ CViewProjectsGrid::CViewProjectsGrid(wxNotebook* pNotebook) :
 
 	pItem = new CTaskItem(
         _("Reset project"),
-        _("Delete all files and tasks associated with this project, "
-          "and get new tasks.  "
-          "You can update the project "
-          "first to report any completed tasks."),
+        _("Delete all files and tasks associated with this project, and get new tasks.  You can update the project first to report any completed tasks."),
         ID_TASK_PROJECT_RESET
     );
     pGroup->m_Tasks.push_back( pItem );
 
 	pItem = new CTaskItem(
         _("Detach"),
-        _("Detach computer from this project.  "
-          "Tasks in progress will be lost "
-          "(use 'Update' first to report any completed tasks)."),
+        _("Detach computer from this project.  Tasks in progress will be lost (use 'Update' first to report any completed tasks)."),
         ID_TASK_PROJECT_DETACH
     );
     pGroup->m_Tasks.push_back( pItem );
