@@ -21,6 +21,9 @@
 #endif
 
 #include "stdwx.h"
+#ifdef __WXMAC__
+#include "MacAccessiblity.h"
+#endif
 #include "diagnostics.h"
 #include "str_util.h"
 #include "mfile.h"
@@ -99,9 +102,11 @@ CSimpleFrame::CSimpleFrame(wxString title, wxIcon* icon, wxIcon* icon32, wxPoint
         _("Close the %s window"), 
         pSkinAdvanced->GetApplicationName().c_str()
     );
+    strMenuName = _("&Close Window");
+    strMenuName += wxT("\tCtrl+W");
     menuFile->Append(
         ID_CLOSEWINDOW,
-        _("&Close Window\tCTRL+W"),
+        strMenuName,
 		strMenuDescription
     );
 
@@ -110,7 +115,7 @@ CSimpleFrame::CSimpleFrame(wxString title, wxIcon* icon, wxIcon* icon32, wxPoint
 
     menuView->Append(
         ID_CHANGEGUI,
-        _("Advanced View...\tCTRL+SHIFT+A"),
+        _("Advanced View...\tCtrl+Shift+A"),
         _("Display the advanced (accessible) graphical interface.")
     );
 
@@ -349,7 +354,8 @@ void CSimpleFrame::OnProjectsAttachToProject() {
 
         wxString strName = wxEmptyString;
         wxString strURL = wxEmptyString;
-        pWizard->Run( strName, strURL, false );
+        std::string foo;
+        pWizard->Run( strName, strURL, foo, false );
 
         if (pWizard)
             pWizard->Destroy();
@@ -381,6 +387,10 @@ void CSimpleFrame::OnConnect(CFrameEvent& WXUNUSED(event)) {
     pDoc->ForceCacheUpdate();
     pDoc->GetCoreClientStatus(status, true);
 
+#ifdef __WXMAC__
+    wxGetApp().GetMacSystemMenu()->BuildMenu();
+#endif
+
 	// If we are connected to the localhost, run a really quick screensaver
     //   test to trigger a firewall popup.
     pDoc->GetConnectedComputerName(strComputer);
@@ -411,7 +421,7 @@ void CSimpleFrame::OnConnect(CFrameEvent& WXUNUSED(event)) {
         strURL = wxString(pis.url.c_str(), wxConvUTF8);
         bCachedCredentials = pis.url.length() && pis.has_account_key;
 
-        pAPWizard->Run(strName, strURL, bCachedCredentials);
+        pAPWizard->Run(strName, strURL, pis.team_name, bCachedCredentials);
     }
 
  	if (pAPWizard){
@@ -454,6 +464,13 @@ CSimplePanel::CSimplePanel(wxWindow* parent) :
 
 	InitEmptyView();
 
+#ifdef __WXMAC__
+    // Have the screen reader tell user to switch to advanced view.
+    oldSimpleGUIWorkCount = -1;
+    
+    SetupMacAccessibilitySupport();
+#endif    
+
     wxLogTrace(wxT("Function Start/End"), wxT("CSimplePanel::CSimplePanel - Overloaded Constructor Function End"));
 }
 
@@ -462,6 +479,10 @@ CSimplePanel::~CSimplePanel()
 {
     wxLogTrace(wxT("Function Start/End"), wxT("CSimplePanel::CSimplePanel - Destructor Function Begin"));
     
+#ifdef __WXMAC__
+    RemoveMacAccessibilitySupport();
+#endif    
+
     wxLogTrace(wxT("Function Start/End"), wxT("CSimplePanel::CSimplePanel - Destructor Function End"));
 }
 
@@ -508,8 +529,9 @@ void CSimplePanel::OnProjectsAttachToProject() {
 
 // called from CSimpleFrame::OnRefreshView()
 void CSimplePanel::OnFrameRender() {
-    CMainDocument*    pDoc = wxGetApp().GetDocument();
+    CMainDocument*      pDoc = wxGetApp().GetDocument();
     wxASSERT(pDoc);
+    int                 workCount = pDoc->GetSimpleGUIWorkCount();
 
     // OnFrameRender() may be called while SimpleGUI initialization is 
     // in progress due to completion of a periodic get_messages RPC, 
@@ -527,7 +549,7 @@ void CSimplePanel::OnFrameRender() {
 	    }
 
 	    // Now check to see if we show the empty state or results
-	    if ( pDoc->GetSimpleGUIWorkCount() > 0 ) {
+	    if ( workCount > 0 ) {
 		    // State changes can cause the BSG to crash if a dialogue is open.
 		    // Defer state change until after the dialogue is closed
 		    if ( (emptyViewInitialized || !notebookViewInitialized) && dlgOpen ) {
@@ -558,6 +580,17 @@ void CSimplePanel::OnFrameRender() {
 		    }
 		    UpdateEmptyView();
 	    }
+            
+#ifdef __WXMAC__
+        //Accessibility
+        // Hide all but top level view from accessibility support so that 
+        // the screen reader will tell user to switch to advanced view.
+        if (oldSimpleGUIWorkCount != workCount) {
+            oldSimpleGUIWorkCount = workCount;
+            HIViewRef simple = (HIViewRef)GetHandle();
+            AccessibilityIgnoreAllChildren(simple, 1);
+        }
+#endif
     }
 }
 
