@@ -1,21 +1,19 @@
-// Berkeley Open Infrastructure for Network Computing
+// This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2005 University of California
+// Copyright (C) 2008 University of California
 //
-// This is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public
-// License as published by the Free Software Foundation;
-// either version 2.1 of the License, or (at your option) any later version.
+// BOINC is free software; you can redistribute it and/or modify it
+// under the terms of the GNU Lesser General Public License
+// as published by the Free Software Foundation,
+// either version 3 of the License, or (at your option) any later version.
 //
-// This software is distributed in the hope that it will be useful,
+// BOINC is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Lesser General Public License for more details.
 //
-// To view the GNU Lesser General Public License visit
-// http://www.gnu.org/copyleft/lesser.html
-// or write to the Free Software Foundation, Inc.,
-// 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+// You should have received a copy of the GNU Lesser General Public License
+// along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
 #ifndef __STDWX_H__
 #define __STDWX_H__
@@ -109,10 +107,15 @@
 #include <wx/sysopt.h>
 #include <wx/cshelp.h>
 #include <wx/grid.h>
-
-#if wxCHECK_VERSION(2,8,0)
+#include <wx/thread.h>
 #include <wx/imaglist.h>
-#endif
+#include <wx/html/htmlwin.h>
+#include <wx/html/htmlproc.h>
+#include <wx/fs_inet.h>
+#include <wx/fs_mem.h>
+#include <wx/dnd.h>
+#include <wx/htmllbox.h>
+
 
 #ifdef _WIN32
 
