@@ -15,9 +15,12 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
+// Screensaver coordinator.
+// Alternates between a "default screensaver"
+// and application graphics for running jobs.
+// Periods are configurable via config file "ss_config.xml".
+// See http://boinc.berkeley.edu/trac/wiki/ScreensaverEnhancements
 
-// System Includes
-//
 #ifdef _WIN32
 #include "boinc_win.h"
 #endif
@@ -471,7 +474,6 @@ void *CScreensaver::DataManagementProc()
     int             exit_status                 = 0;
     
     char*           default_ss_dir_path         = NULL;
-    char*           default_data_dir_path       = NULL;
     char            full_path[1024];
 
     BOINCTRACE(_T("CScreensaver::DataManagementProc - Display screen saver loading message\n"));
@@ -488,15 +490,10 @@ void *CScreensaver::DataManagementProc()
     m_bScience_gfx_running = false;
     m_bDefault_gfx_running = false;
     m_bShow_default_ss_first = false;
-    m_fGFXDefaultPeriod = GFX_DEFAULT_PERIOD;
-    m_fGFxSciencePeriod = GFX_SCIENCE_PERIOD;
-    m_fGFXChangePeriod = GFX_CHANGE_PERIOD;
 
 #ifdef __APPLE__
-    default_data_dir_path = "/Library/Application Support/BOINC Data";
-    default_ss_dir_path = default_data_dir_path;
+    default_ss_dir_path = "/Library/Application Support/BOINC Data";
 #else
-    default_data_dir_path = (char*)m_strBOINCDataDirectory.c_str();
     default_ss_dir_path = (char*)m_strBOINCInstallDirectory.c_str();
 #endif
 
@@ -504,8 +501,6 @@ void *CScreensaver::DataManagementProc()
     strlcat(full_path, PATH_SEPARATOR, sizeof(full_path));
     strlcat(full_path, THE_DEFAULT_SS_EXECUTABLE, sizeof(full_path));
     
-    GetDisplayPeriods(default_data_dir_path);
-    
     if (boinc_file_exists(full_path)) {
         m_bDefault_ss_exists = true;
     } else {
@@ -555,7 +550,7 @@ void *CScreensaver::DataManagementProc()
         // ***
 
         // Blank screen saver?
-        if ((m_dwBlankScreen) && (time(0) > m_dwBlankTime)) {
+        if ((m_dwBlankScreen) && (time(0) > m_dwBlankTime) && (m_dwBlankTime > 0)) {
             BOINCTRACE(_T("CScreensaver::DataManagementProc - Time to blank\n"));
             SetError(FALSE, SCRAPPERR_SCREENSAVERBLANKED);    // Blanked - hide moving BOINC logo
             m_QuitDataManagementProc = true;
@@ -595,8 +590,8 @@ void *CScreensaver::DataManagementProc()
         }
         
         // Time to switch to default graphics phase?
-        if (m_bDefault_ss_exists && (ss_phase == SCIENCE_SS_PHASE)) {
-            if (science_phase_start_time && ((dtime() - science_phase_start_time) > m_fGFxSciencePeriod)) {
+        if (m_bDefault_ss_exists && (ss_phase == SCIENCE_SS_PHASE) && (m_fGFXDefaultPeriod > 0)) {
+            if (science_phase_start_time && ((dtime() - science_phase_start_time) > m_fGFXSciencePeriod)) {
                 if (!m_bDefault_gfx_running) {
                     switch_to_default_gfx = true;
                 }
@@ -612,7 +607,7 @@ void *CScreensaver::DataManagementProc()
         }
         
         // Time to switch to science graphics phase?
-        if ((ss_phase == DEFAULT_SS_PHASE) && m_bConnected) {
+        if ((ss_phase == DEFAULT_SS_PHASE) && m_bConnected && (m_fGFXSciencePeriod > 0)) {
             if (default_phase_start_time && 
                     ((dtime() - default_phase_start_time + default_saver_duration_in_science_phase) 
                     > m_fGFXDefaultPeriod)) {
@@ -630,10 +625,12 @@ void *CScreensaver::DataManagementProc()
         }
 
         // Core client suspended?
-        if (suspend_reason && !(suspend_reason & SUSPEND_REASON_CPU_USAGE_LIMIT)) {
-            SetError(TRUE, m_hrError);          // No GFX App is running: show moving BOINC logo
-            if (m_bDefault_ss_exists && !m_bDefault_gfx_running) {
-                switch_to_default_gfx = true;
+        if (suspend_reason && !(suspend_reason & (SUSPEND_REASON_CPU_THROTTLE | SUSPEND_REASON_CPU_USAGE))) {
+            if (!m_bDefault_gfx_running) {
+                SetError(TRUE, m_hrError);          // No GFX App is running: show moving BOINC logo
+                if (m_bDefault_ss_exists) {
+                    switch_to_default_gfx = true;
+                }
             }
         }
         
@@ -665,7 +662,7 @@ void *CScreensaver::DataManagementProc()
                         if (ss_phase == SCIENCE_SS_PHASE) {
                             default_saver_start_time_in_science_phase = dtime();
                         }
-                        SetError(FALSE, m_hrError);          // A GFX App is running: hide moving BOINC logo
+                        SetError(FALSE, SCRAPPERR_BOINCSCREENSAVERLOADING);    // A GFX App is running: hide moving BOINC logo
                     }
                 }
             }
@@ -675,10 +672,12 @@ void *CScreensaver::DataManagementProc()
         
 #if SIMULATE_NO_GRAPHICS /* FOR TESTING */
 
-        SetError(TRUE, m_hrError);          // No GFX App is running: show moving BOINC logo
-        if (m_bDefault_ss_exists && !m_bDefault_gfx_running) {
-            switch_to_default_gfx = true;
-        }
+            if (!m_bDefault_gfx_running) {
+                SetError(TRUE, m_hrError);          // No GFX App is running: show moving BOINC logo
+                if (m_bDefault_ss_exists) {
+                    switch_to_default_gfx = true;
+                }
+            }
 
 #else                   /* NORMAL OPERATION */
 
@@ -686,7 +685,7 @@ void *CScreensaver::DataManagementProc()
                 // Is the current graphics app's associated task still running?
                 
                 if ((m_hGraphicsApplication) || (graphics_app_result_ptr)) {
-                    iResultCount = results.results.size();
+                    iResultCount = (int)results.results.size();
                     graphics_app_result_ptr = NULL;
 
                     // Find the current task in the new results vector (if it still exists)
@@ -718,7 +717,7 @@ void *CScreensaver::DataManagementProc()
                         }
                     }
 
-                     if (last_change_time && ((dtime() - last_change_time) > m_fGFXChangePeriod)) {
+                     if (last_change_time && (m_fGFXChangePeriod > 0) && ((dtime() - last_change_time) > m_fGFXChangePeriod) ) {
                         if (count_active_graphic_apps(results, previous_result_ptr) > 0) {
                             if (previous_result_ptr) {
                                 BOINCTRACE(_T("CScreensaver::DataManagementProc - time to change: %s / %s\n"), 
@@ -763,7 +762,7 @@ void *CScreensaver::DataManagementProc()
                             graphics_app_result_ptr = NULL;
                             m_bScience_gfx_running = false;
                         } else {
-                            SetError(FALSE, m_hrError);          // A GFX App is running: hide moving BOINC logo
+                            SetError(FALSE, SCRAPPERR_BOINCSCREENSAVERLOADING);  // A GFX App is running: hide moving BOINC logo
                             last_change_time = dtime();
                             m_bScience_gfx_running = true;
                             // Make a local copy of current result, since original pointer 
@@ -777,10 +776,12 @@ void *CScreensaver::DataManagementProc()
                         }
                     }
                 } else {
-                    SetError(TRUE, m_hrError);          // No GFX App is running: show moving BOINC logo
-                    // We can't run a science graphics app, so run the default graphics if available
-                    if (m_bDefault_ss_exists && !m_bDefault_gfx_running) {
-                        switch_to_default_gfx = true;
+                    if (!m_bDefault_gfx_running) {
+                        // We can't run a science graphics app, so run the default graphics if available
+                        SetError(TRUE, m_hrError); 
+                        if (m_bDefault_ss_exists) {
+                            switch_to_default_gfx = true;
+                        }
                     }
 
                 }   // End if no science graphics available
@@ -801,7 +802,7 @@ void *CScreensaver::DataManagementProc()
                     } else {
                         m_bDefault_gfx_running = true;
                         default_saver_start_time_in_science_phase = dtime();
-                        SetError(FALSE, m_hrError);          // A GFX App is running: hide moving BOINC logo
+                        SetError(FALSE, SCRAPPERR_BOINCSCREENSAVERLOADING);    // Default GFX App is running: hide moving BOINC logo
                     }
                 }
             }
@@ -829,7 +830,7 @@ void *CScreensaver::DataManagementProc()
                     }
                     killing_default_gfx = false;
                 }
-                SetError(TRUE, m_hrError);      // No GFX App is running: show moving BOINC logo
+                SetError(TRUE, SCRAPPERR_BOINCNOGRAPHICSAPPSEXECUTING); // No GFX App is running: show moving BOINC logo
                 m_hGraphicsApplication = 0;
                 graphics_app_result_ptr = NULL;
                 m_bDefault_gfx_running = false;
@@ -868,12 +869,25 @@ bool CScreensaver::HasProcessExited(pid_t pid, int &exitCode) {
 #endif
 
 
-void CScreensaver::GetDisplayPeriods(char *dir_path) {
-    char buf[1024];
-    FILE* f;
-    MIOFILE mf;
+void CScreensaver::GetDefaultDisplayPeriods(struct ss_periods &periods)
+{
+    char*           default_data_dir_path = NULL;
+    char            buf[1024];
+    FILE*           f;
+    MIOFILE         mf;
 
-    strlcpy(buf, dir_path, sizeof(buf));
+    periods.GFXDefaultPeriod = GFX_DEFAULT_PERIOD;
+    periods.GFXSciencePeriod = GFX_SCIENCE_PERIOD;
+    periods.GFXChangePeriod = GFX_CHANGE_PERIOD;
+    periods.Show_default_ss_first = false;
+
+#ifdef __APPLE__
+    default_data_dir_path = "/Library/Application Support/BOINC Data";
+#else
+    default_data_dir_path = (char*)m_strBOINCDataDirectory.c_str();
+#endif
+
+    strlcpy(buf, default_data_dir_path, sizeof(buf));
     strlcat(buf, PATH_SEPARATOR, sizeof(buf));
     strlcat(buf, THE_SS_CONFIG_FILE, sizeof(buf));
 
@@ -884,14 +898,14 @@ void CScreensaver::GetDisplayPeriods(char *dir_path) {
     XML_PARSER xp(&mf);
 
     while (mf.fgets(buf, sizeof(buf))) {
-        if (parse_bool(buf, "default_ss_first", m_bShow_default_ss_first)) continue;
-        if (parse_double(buf, "<default_gfx_duration>", m_fGFXDefaultPeriod)) continue;
-        if (parse_double(buf, "<science_gfx_duration>", m_fGFxSciencePeriod)) continue;
-        if (parse_double(buf, "<science_gfx_change_interval>", m_fGFXChangePeriod)) continue;
+        if (parse_bool(buf, "default_ss_first", periods.Show_default_ss_first)) continue;
+        if (parse_double(buf, "<default_gfx_duration>", periods.GFXDefaultPeriod)) continue;
+        if (parse_double(buf, "<science_gfx_duration>", periods.GFXSciencePeriod)) continue;
+        if (parse_double(buf, "<science_gfx_change_interval>", periods.GFXChangePeriod)) continue;
         
     }
     fclose(f);
     
-    BOINCTRACE(_T("CScreensaver::GetDisplayPeriods: m_bShow_default_ss_first=%d, m_fGFXDefaultPeriod=%f, m_fGFxSciencePeriod=%f, m_fGFXChangePeriod=%f\n"),
-                    (int)m_bShow_default_ss_first, m_fGFXDefaultPeriod, m_fGFxSciencePeriod, m_fGFXChangePeriod);
+    BOINCTRACE(_T("CScreensaver::GetDefaultDisplayPeriods: m_bShow_default_ss_first=%d, m_fGFXDefaultPeriod=%f, m_fGFXSciencePeriod=%f, m_fGFXChangePeriod=%f\n"),
+                    (int)periods.Show_default_ss_first, periods.GFXDefaultPeriod, periods.GFXSciencePeriod, periods.GFXChangePeriod);
 }
