@@ -48,7 +48,6 @@ function success($x) {
 ";
 }
 
-
 xml_header();
 $retval = db_init_xml();
 if ($retval) xml_error($retval);
@@ -59,14 +58,15 @@ if (!$user) {
     xml_error(-136);
 }
 
-$name = process_user_text(get_str("name", true));
+$name = BoincDb::escape_string(get_str("name", true));
 $country = get_str("country", true);
 if ($country && !is_valid_country($country)) {
     xml_error(-1, "invalid country");
 }
-$postal_code = process_user_text(get_str("postal_code", true));
-$global_prefs = process_user_text(get_str("global_prefs", true));
-$project_prefs = process_user_text(get_str("project_prefs", true));
+$country = BoincDb::escape_string($country);
+$postal_code = BoincDb::escape_string(get_str("postal_code", true));
+$global_prefs = BoincDb::escape_string(get_str("global_prefs", true));
+$project_prefs = BoincDb::escape_string(get_str("project_prefs", true));
 
 // Do processing on project prefs so that we don't overwrite project-specific
 // settings if AMS has no idea about them
@@ -78,13 +78,22 @@ if (stripos($project_prefs, "<project_specific>") === false) {
     $project_prefs = str_ireplace("<project_preferences>", "<project_preferences>\n".$orig_project_specific, $project_prefs);
 }
 
-$url = process_user_text(get_str("url", true));
-$send_email = process_user_text(get_str("send_email", true));
-$show_hosts = process_user_text(get_str("show_hosts", true));
+$url = BoincDb::escape_string(get_str("url", true));
+$send_email = BoincDb::escape_string(get_str("send_email", true));
+$show_hosts = BoincDb::escape_string(get_str("show_hosts", true));
 $teamid = get_int("teamid", true);
-$venue = process_user_text(get_str("venue", true));
-$email_addr = strtolower(process_user_text(get_str("email_addr", true)));
-$password_hash = process_user_text(get_str("password_hash", true));
+$venue = BoincDb::escape_string(get_str("venue", true));
+$email_addr = get_str("email_addr", true);
+if ($email_addr) {
+    if (!is_valid_email_addr($email_addr)) {
+        xml_error(-205, "Invalid email address");
+    }
+    if (is_banned_email_addr($email_addr)) {
+        xml_error(-205, "Invalid email address");
+    }
+    $email_addr = strtolower(BoincDb::escape_string($email_addr));
+}
+$password_hash = BoincDb::escape_string(get_str("password_hash", true));
 
 $query = "";
 if ($name) {
