@@ -22,6 +22,7 @@
 
 require_once('../inc/forum_email.inc');
 require_once('../inc/forum.inc');
+require_once('../inc/bbcode_html.inc');
 require_once('../inc/akismet.inc');
 
 $logged_in_user = get_logged_in_user();
@@ -35,6 +36,8 @@ $forum = BoincForum::lookup_id($forumid);
 check_create_thread_access($logged_in_user, $forum);
 
 $title = post_str("title", true);
+if (!$title) $title = get_str("title", true);
+$force_title = get_str("force_title", true);
 $content = post_str("content", true);
 $preview = post_str("preview", true);
 $warning = null;
@@ -59,7 +62,7 @@ if ($content && $title && (!$preview)){
     }
 }
 
-page_head('Create new thread');
+page_head('Create new thread','','','', $bbcode_js);
 show_forum_header($logged_in_user);
 
 if ($warning) {
@@ -84,7 +87,7 @@ if ($preview == tra("Preview")) {
     echo "</div>\n";
 }
 
-echo "<form action=\"forum_post.php?id=".$forum->id."\" method=\"POST\">\n";
+echo "<form action=\"forum_post.php?id=".$forum->id."\" method=\"POST\" name=\"post\" onsubmit=\"return checkForm(this)\">\n";
 echo form_tokens($logged_in_user->authenticator);
 
 start_table();
@@ -97,12 +100,17 @@ if ($content && !$title) {
     $submit_help = "<br /><font color=\"red\">Remember to add a title</font>";
 }
 
-row2(tra("Title").$submit_help,
+if ($force_title && $title){
+    row2(tra("Title"), htmlspecialchars($title)."<input type=\"hidden\" name=\"title\" value=\"".htmlspecialchars($title)."\">");
+} else {
+    row2(tra("Title").$submit_help,
     "<input type=\"text\" name=\"title\" size=\"62\" value=\"".htmlspecialchars($title)."\">"
-);
+    );
+}
+
 //Message
 row2(tra("Message").html_info().post_warning().$body_help,
-    "<textarea name=\"content\" rows=\"12\" cols=\"54\">".htmlspecialchars($content)."</textarea>"
+     $bbcode_html."<textarea name=\"content\" rows=\"12\" cols=\"54\">".htmlspecialchars($content)."</textarea>"
 );
 
 if (!$logged_in_user->prefs->no_signature_by_default) {
@@ -121,5 +129,5 @@ echo "</form>\n";
 
 page_tail();
 
-$cvs_version_tracker[]="\$Id: forum_post.php 16189 2008-10-11 18:13:33Z davea $";
+$cvs_version_tracker[]="\$Id: forum_post.php 18487 2009-06-23 17:15:17Z davea $";
 ?>
