@@ -53,7 +53,7 @@ function user_host_table_start($private, $sort, $rev, $show_all) {
     start_table();
     echo "<tr>";
     $url = link_url_rev($sort, "id", $rev, $show_all);
-    echo "<th><a href=$url>Computer ID</a><br><span class=note>Click for more info</span></th>\n";
+    echo "<th><a href=$url>Computer ID</a></th>\n";
     if ($private) {
         $url = link_url_rev($sort, "name", $rev, $show_all);
         echo "<th><a href=$url>Name</a></th>\n";
@@ -67,7 +67,9 @@ function user_host_table_start($private, $sort, $rev, $show_all) {
     $url = link_url_rev($sort, "total_credit", $rev, $show_all);
     echo "<th><a href=$url>Total credit</a></th>\n";
     $url = link_url_rev($sort, "cpu", $rev, $show_all);
-    echo "<th><a href=$url>CPU type</a></th>\n";
+    echo "<th><a href=$url>CPU</a></th>\n";
+    $url = link_url_rev($sort, "gpu", $rev, $show_all);
+    echo "<th><a href=$url>GPU</a></th>\n";
     $url = link_url_rev($sort, "os", $rev, $show_all);
     echo "<th><a href=$url>Operating System</a></th>\n";
     $url = link_url_rev($sort, "rpc_time", $rev, $show_all);
@@ -92,6 +94,7 @@ case "expavg_credit": $sort_clause = "expavg_credit"; $desc = true; break;
 case "name": $sort_clause = "domain_name"; break;
 case "id": $sort_clause = "id"; break;
 case "cpu": $sort_clause = "p_vendor"; break;
+case "gpu": $sort_clause = "serialnum"; break;
 case "os": $sort_clause = "os_name"; break;
 case "venue": $sort_clause = "venue"; break;
 default:
@@ -122,7 +125,7 @@ if ($userid) {
     // At this point, we know that $userid, $show_all and $sort all have
     // valid values.
     //
-    $cache_args="userid=$userid&show_all=$show_all&sort=$sort&rev=$rev";
+    $cache_args="userid=$userid&amp;show_all=$show_all&amp;sort=$sort&amp;rev=$rev";
     start_cache(USER_PAGE_TTL, $cache_args);
     if ($user->show_hosts) {
         page_head("Computers belonging to $user->name");
