@@ -238,14 +238,16 @@ int PROJECT::parse(MIOFILE& in) {
         if (parse_double(buf, "<min_rpc_time>", min_rpc_time)) continue;
         if (parse_double(buf, "<download_backoff>", download_backoff)) continue;
         if (parse_double(buf, "<upload_backoff>", upload_backoff)) continue;
-        if (parse_double(buf, "<short_term_debt>", short_term_debt)) continue;
+        if (parse_double(buf, "<short_term_debt>", cpu_short_term_debt)) continue;
         if (parse_double(buf, "<long_term_debt>", cpu_long_term_debt)) continue;
         if (parse_double(buf, "<cpu_backoff_time>", cpu_backoff_time)) continue;
         if (parse_double(buf, "<cpu_backoff_interval>", cpu_backoff_interval)) continue;
         if (parse_double(buf, "<cuda_debt>", cuda_debt)) continue;
+        if (parse_double(buf, "<cuda_short_term_debt>", cuda_short_term_debt)) continue;
         if (parse_double(buf, "<cuda_backoff_time>", cuda_backoff_time)) continue;
         if (parse_double(buf, "<cuda_backoff_interval>", cuda_backoff_interval)) continue;
         if (parse_double(buf, "<ati_debt>", ati_debt)) continue;
+        if (parse_double(buf, "<ati_short_term_debt>", ati_short_term_debt)) continue;
         if (parse_double(buf, "<ati_backoff_time>", ati_backoff_time)) continue;
         if (parse_double(buf, "<ati_backoff_interval>", ati_backoff_interval)) continue;
         if (parse_double(buf, "<duration_correction_factor>", duration_correction_factor)) continue;
@@ -258,6 +260,7 @@ int PROJECT::parse(MIOFILE& in) {
         if (parse_bool(buf, "scheduler_rpc_in_progress", scheduler_rpc_in_progress)) continue;
         if (parse_bool(buf, "attached_via_acct_mgr", attached_via_acct_mgr)) continue;
         if (parse_bool(buf, "detach_when_done", detach_when_done)) continue;
+        if (parse_bool(buf, "trickle_up_pending", trickle_up_pending)) continue;
         if (match_tag(buf, "<gui_urls>")) {
             while (in.fgets(buf, 256)) {
                 if (match_tag(buf, "</gui_urls>")) break;
@@ -273,6 +276,9 @@ int PROJECT::parse(MIOFILE& in) {
         }
         if (parse_double(buf, "<project_files_downloaded_time>", project_files_downloaded_time)) continue;
         if (parse_double(buf, "<last_rpc_time>", last_rpc_time)) continue;
+        if (parse_bool(buf, "no_cpu_pref", no_cpu_pref)) continue;
+        if (parse_bool(buf, "no_cuda_pref", no_cuda_pref)) continue;
+        if (parse_bool(buf, "no_ati_pref", no_ati_pref)) continue;
     }
     return ERR_XML_PARSE;
 }
@@ -293,7 +299,7 @@ void PROJECT::clear() {
     min_rpc_time = 0;
     download_backoff = 0;
     upload_backoff = 0;
-    short_term_debt = 0;
+    cpu_short_term_debt = 0;
     cpu_long_term_debt = 0;
     cpu_backoff_time = 0;
     cpu_backoff_interval = 0;
@@ -313,10 +319,14 @@ void PROJECT::clear() {
     scheduler_rpc_in_progress = false;
     attached_via_acct_mgr = false;
     detach_when_done = false;
+    trickle_up_pending = false;
     project_files_downloaded_time = 0;
     last_rpc_time = 0;
     gui_urls.clear();
     statistics.clear();
+    no_cpu_pref = false;
+    no_cuda_pref = false;
+    no_ati_pref = false;
 }
 
 APP::APP() {
@@ -440,6 +450,7 @@ int RESULT::parse(MIOFILE& in) {
         if (parse_bool(buf, "suspended_via_gui", suspended_via_gui)) continue;
         if (parse_bool(buf, "project_suspended_via_gui", project_suspended_via_gui)) continue;
         if (parse_bool(buf, "coproc_missing", coproc_missing)) continue;
+        if (parse_bool(buf, "gpu_mem_wait", gpu_mem_wait)) continue;
         if (match_tag(buf, "<active_task>")) {
             active_task = true;
             continue;
@@ -459,6 +470,7 @@ int RESULT::parse(MIOFILE& in) {
         }
         if (parse_int(buf, "<app_version_num>", app_version_num)) continue;
         if (parse_int(buf, "<slot>", slot)) continue;
+        if (parse_int(buf, "<pid>", pid)) continue;
         if (parse_double(buf, "<checkpoint_cpu_time>", checkpoint_cpu_time)) continue;
         if (parse_double(buf, "<current_cpu_time>", current_cpu_time)) continue;
         if (parse_double(buf, "<elapsed_time>", elapsed_time)) continue;
@@ -498,11 +510,13 @@ void RESULT::clear() {
     suspended_via_gui = false;
     project_suspended_via_gui = false;
     coproc_missing = false;
+    gpu_mem_wait = false;
 
     active_task = false;
     active_task_state = 0;
     app_version_num = 0;
     slot = -1;
+    pid = 0;
     checkpoint_cpu_time = 0;
     current_cpu_time = 0;
     fraction_done = 0;
@@ -930,6 +944,7 @@ int PROJECT_INIT_STATUS::parse(MIOFILE& in) {
         if (match_tag(buf, "</get_project_init_status>")) return 0;
         if (parse_str(buf, "<url>", url)) continue;
         if (parse_str(buf, "<name>", name)) continue;
+        if (parse_str(buf, "<team_name>", team_name)) continue;
         if (parse_bool(buf, "has_account_key", has_account_key)) continue;
     }
     return ERR_XML_PARSE;
@@ -1013,6 +1028,7 @@ void ACCOUNT_IN::clear() {
     email_addr.clear();
     user_name.clear();
     passwd.clear();
+    team_name.clear();
 }
 
 ACCOUNT_OUT::ACCOUNT_OUT() {
@@ -1056,12 +1072,15 @@ int CC_STATUS::parse(MIOFILE& in) {
         if (parse_bool(buf, "ams_password_error", ams_password_error)) continue;
         if (parse_bool(buf, "manager_must_quit", manager_must_quit)) continue;
         if (parse_int(buf, "<task_suspend_reason>", task_suspend_reason)) continue;
-        if (parse_int(buf, "<network_suspend_reason>", network_suspend_reason)) continue;
         if (parse_int(buf, "<task_mode>", task_mode)) continue;
-        if (parse_int(buf, "<network_mode>", network_mode)) continue;
         if (parse_int(buf, "<task_mode_perm>", task_mode_perm)) continue;
-        if (parse_int(buf, "<network_mode_perm>", network_mode_perm)) continue;
 		if (parse_double(buf, "<task_mode_delay>", task_mode_delay)) continue;
+        if (parse_int(buf, "<gpu_mode>", gpu_mode)) continue;
+        if (parse_int(buf, "<gpu_mode_perm>", gpu_mode_perm)) continue;
+		if (parse_double(buf, "<gpu_mode_delay>", gpu_mode_delay)) continue;
+        if (parse_int(buf, "<network_suspend_reason>", network_suspend_reason)) continue;
+        if (parse_int(buf, "<network_mode>", network_mode)) continue;
+        if (parse_int(buf, "<network_mode_perm>", network_mode_perm)) continue;
 		if (parse_double(buf, "<network_mode_delay>", network_mode_delay)) continue;
         if (parse_bool(buf, "disallow_attach", disallow_attach)) continue;
         if (parse_bool(buf, "simple_gui_only", simple_gui_only)) continue;
@@ -1632,6 +1651,24 @@ int RPC_CLIENT::set_run_mode(int mode, double duration) {
     return retval;
 }
 
+int RPC_CLIENT::set_gpu_mode(int mode, double duration) {
+    int retval;
+    SET_LOCALE sl;
+    char buf[256];
+    RPC rpc(this);
+
+    sprintf(buf, 
+        "<set_gpu_mode>\n"
+        "%s\n"
+        "  <duration>%f</duration>\n"
+        "</set_gpu_mode>\n",
+        mode_name(mode), duration
+    );
+
+    retval = rpc.do_rpc(buf);
+    return retval;
+}
+
 int RPC_CLIENT::set_network_mode(int mode, double duration) {
     int retval;
     SET_LOCALE sl;
@@ -2020,11 +2057,13 @@ int RPC_CLIENT::create_account(ACCOUNT_IN& ai) {
         "   <email_addr>%s</email_addr>\n"
         "   <passwd_hash>%s</passwd_hash>\n"
         "   <user_name>%s</user_name>\n"
+        "   <team_name>%s</team_name>\n"
         "</create_account>\n",
         ai.url.c_str(),
         ai.email_addr.c_str(),
         passwd_hash.c_str(),
-        ai.user_name.c_str()
+        ai.user_name.c_str(),
+        ai.team_name.c_str()
     );
 
     retval =  rpc.do_rpc(buf);
@@ -2247,7 +2286,7 @@ int RPC_CLIENT::set_debts(vector<PROJECT> projects) {
             "        <long_term_debt>%f</long_term_debt>\n"
             "    </project>\n",
             p.master_url.c_str(),
-            p.short_term_debt,
+            p.cpu_short_term_debt,
             p.cpu_long_term_debt
         );
         s += string(buf);
@@ -2258,4 +2297,3 @@ int RPC_CLIENT::set_debts(vector<PROJECT> projects) {
 }
 
 
-const char *BOINC_RCSID_90e8b8d168="$Id: gui_rpc_client_ops.cpp 19318 2009-10-16 19:07:56Z romw $";
