@@ -28,8 +28,7 @@ extern int md5_block(const unsigned char* data, int nbytes, char* output);
 
 extern std::string md5_string(const unsigned char* data, int nbytes);
 
-inline std::string md5_string(std::string const& data)
-{
+inline std::string md5_string(std::string const& data) {
     return md5_string((const unsigned char*) data.c_str(), (int)data.size());
 }
 
