@@ -40,7 +40,7 @@
 
 
 MFILE::MFILE() {
-    buf = 0;
+    buf = (char*)malloc(64*1024);
     len = 0;
 }
 
@@ -54,6 +54,17 @@ int MFILE::open(const char* path, const char* mode) {
     return 0;
 }
 
+// seems like Win's realloc is stupid,  Make it smart.
+//
+static inline char* realloc_aux(char* p, int len) {
+#ifdef _WIN32
+    if (_msize(p) >= len) return p;
+    return (char*) realloc(p, len*2);
+#else
+    return (char*) realloc(p, len);
+#endif
+}
+
 #define BUFSIZE 100000
 
 int MFILE::vprintf(const char* format, va_list ap) {
@@ -68,7 +79,7 @@ int MFILE::vprintf(const char* format, va_list ap) {
         return -1;
     }
     n = (int)strlen(buf2);
-    buf = (char*)realloc(buf, len+n+1);
+    buf = (char*)realloc_aux(buf, len+n+1);
     if (!buf) {
         fprintf(stderr, "ERROR: realloc() failed in MFILE::vprintf()\n");
         exit(1);
@@ -90,7 +101,7 @@ int MFILE::printf(const char* format, ...) {
 }
 
 size_t MFILE::write(const void *ptr, size_t size, size_t nitems) {
-    buf = (char *)realloc( buf, len+(size*nitems)+1 );
+    buf = (char *)realloc_aux( buf, len+(size*nitems)+1 );
     if (!buf) {
         fprintf(stderr, "ERROR: realloc() failed in MFILE::write()\n");
         exit(1);
@@ -102,7 +113,7 @@ size_t MFILE::write(const void *ptr, size_t size, size_t nitems) {
 }
 
 int MFILE::_putchar(char c) {
-    buf = (char*)realloc(buf, len+1+1);
+    buf = (char*)realloc_aux(buf, len+1+1);
     if (!buf) {
         fprintf(stderr, "ERROR: realloc() failed in MFILE::_putchar()\n");
         exit(1);
@@ -115,7 +126,7 @@ int MFILE::_putchar(char c) {
 
 int MFILE::puts(const char* p) {
     int n = (int)strlen(p);
-    buf = (char*)realloc(buf, len+n+1);
+    buf = (char*)realloc_aux(buf, len+n+1);
     if (!buf) {
         fprintf(stderr, "ERROR: realloc() failed in MFILE::puts()\n");
         exit(1);
@@ -159,4 +170,3 @@ void MFILE::get_buf(char*& b, int& l) {
     len = 0;
 }
 
-const char *BOINC_RCSID_8de9facdd7 = "$Id: mfile.cpp 18594 2009-07-10 22:59:45Z davea $";
