@@ -52,6 +52,7 @@ void GLOBAL_PREFS_MASK::set_all() {
     run_gpu_if_user_active = true;
     idle_time_to_run = true;
     suspend_if_no_recent_input = true;
+    suspend_cpu_usage = 0;
     start_hour = true;
     end_hour = true;
     net_start_hour = true;
@@ -76,6 +77,8 @@ void GLOBAL_PREFS_MASK::set_all() {
     max_bytes_sec_up = true;
     max_bytes_sec_down = true;
     cpu_usage_limit = true;
+    daily_xfer_limit_mb = true;
+    daily_xfer_period_days = true;
 }
 
 bool GLOBAL_PREFS_MASK::are_prefs_set() {
@@ -84,6 +87,7 @@ bool GLOBAL_PREFS_MASK::are_prefs_set() {
     if (run_gpu_if_user_active) return true;
     if (idle_time_to_run) return true;
     if (suspend_if_no_recent_input) return true;
+    if (suspend_cpu_usage) return true;
     if (start_hour) return true;
     if (end_hour) return true;
     if (net_start_hour) return true;
@@ -108,6 +112,8 @@ bool GLOBAL_PREFS_MASK::are_prefs_set() {
     if (max_bytes_sec_up) return true;
     if (max_bytes_sec_down) return true;
     if (cpu_usage_limit) return true;
+    if (daily_xfer_limit_mb) return true;
+    if (daily_xfer_period_days) return true;
     return false;
 }
 
@@ -205,6 +211,7 @@ void GLOBAL_PREFS::defaults() {
     run_gpu_if_user_active = false;
     idle_time_to_run = 3;
     suspend_if_no_recent_input = 0;
+    suspend_cpu_usage = 25;
     cpu_times.clear();
     net_times.clear();
     leave_apps_in_memory = false;
@@ -226,6 +233,8 @@ void GLOBAL_PREFS::defaults() {
     max_bytes_sec_up = 0;
     max_bytes_sec_down = 0;
     cpu_usage_limit = 100;
+    daily_xfer_limit_mb = 0;
+    daily_xfer_period_days = 0;
 
     // don't initialize source_project, source_scheduler,
     // mod_time, host_specific here
@@ -330,6 +339,7 @@ int GLOBAL_PREFS::parse_override(
     char tag[256], buf2[256], attrs[256];
     bool in_venue = false, in_correct_venue=false, is_tag;
     double dtemp;
+    int itemp;
 
     found_venue = false;
     mask.clear();
@@ -398,6 +408,10 @@ int GLOBAL_PREFS::parse_override(
             mask.suspend_if_no_recent_input = true;
             continue;
         }
+        if (xp.parse_double(tag, "suspend_cpu_usage", suspend_cpu_usage)) {
+            mask.suspend_cpu_usage = true;
+            continue;
+        }
         if (xp.parse_double(tag, "start_hour", cpu_times.start_hour)) {
             mask.start_hour = true;
             continue;
@@ -511,6 +525,20 @@ int GLOBAL_PREFS::parse_override(
             }
             continue;
         }
+        if (xp.parse_double(tag, "daily_xfer_limit_mb", dtemp)) {
+            if (dtemp >= 0) {
+                daily_xfer_limit_mb = dtemp;
+                mask.daily_xfer_limit_mb = true;
+            }
+            continue;
+        }
+        if (xp.parse_int(tag, "daily_xfer_period_days", itemp)) {
+            if (itemp >= 0) {
+                daily_xfer_period_days = itemp;
+                mask.daily_xfer_period_days = true;
+            }
+            continue;
+        }
         if (xp.parse_bool(tag, "host_specific", host_specific)) {
             continue;
         }
@@ -560,6 +588,7 @@ int GLOBAL_PREFS::write(MIOFILE& f) {
         "   <run_if_user_active>%d</run_if_user_active>\n"
         "   <run_gpu_if_user_active>%d</run_gpu_if_user_active>\n"
         "   <suspend_if_no_recent_input>%f</suspend_if_no_recent_input>\n"
+        "   <suspend_cpu_usage>%f</suspend_cpu_usage>\n"
         "   <start_hour>%f</start_hour>\n"
         "   <end_hour>%f</end_hour>\n"
         "   <net_start_hour>%f</net_start_hour>\n"
@@ -582,13 +611,16 @@ int GLOBAL_PREFS::write(MIOFILE& f) {
         "   <idle_time_to_run>%f</idle_time_to_run>\n"
         "   <max_bytes_sec_up>%f</max_bytes_sec_up>\n"
         "   <max_bytes_sec_down>%f</max_bytes_sec_down>\n"
-        "   <cpu_usage_limit>%f</cpu_usage_limit>\n",
+        "   <cpu_usage_limit>%f</cpu_usage_limit>\n"
+        "   <daily_xfer_limit_mb>%f</daily_xfer_limit_mb>\n"
+        "   <daily_xfer_period_days>%d</daily_xfer_period_days>\n",
         source_project,
         mod_time,
         run_on_batteries?1:0,
         run_if_user_active?1:0,
         run_gpu_if_user_active?1:0,
         suspend_if_no_recent_input,
+        suspend_cpu_usage,
         cpu_times.start_hour,
         cpu_times.end_hour,
         net_times.start_hour,
@@ -611,7 +643,9 @@ int GLOBAL_PREFS::write(MIOFILE& f) {
         idle_time_to_run,
         max_bytes_sec_up,
         max_bytes_sec_down,
-        cpu_usage_limit
+        cpu_usage_limit,
+        daily_xfer_limit_mb,
+        daily_xfer_period_days
     );
     if (max_ncpus) {
         f.printf("   <max_cpus>%d</max_cpus>\n", max_ncpus);
@@ -685,6 +719,12 @@ int GLOBAL_PREFS::write_subset(MIOFILE& f, GLOBAL_PREFS_MASK& mask) {
             suspend_if_no_recent_input
         );
     }
+    if (mask.suspend_cpu_usage) {
+
+        f.printf("   <suspend_cpu_usage>%f</suspend_cpu_usage>\n",
+            suspend_cpu_usage
+        );
+    }
     if (mask.start_hour) {
         f.printf("   <start_hour>%f</start_hour>\n", cpu_times.start_hour);
     }
@@ -762,13 +802,15 @@ int GLOBAL_PREFS::write_subset(MIOFILE& f, GLOBAL_PREFS_MASK& mask) {
     if (mask.cpu_usage_limit) {
         f.printf("   <cpu_usage_limit>%f</cpu_usage_limit>\n", cpu_usage_limit);
     }
+    if (mask.daily_xfer_limit_mb) {
+        f.printf("   <daily_xfer_limit_mb>%f</daily_xfer_limit_mb>\n", daily_xfer_limit_mb);
+    }
+    if (mask.daily_xfer_period_days) {
+        f.printf("   <daily_xfer_period_days>%d</daily_xfer_period_days>\n", daily_xfer_period_days);
+    }
 
     write_day_prefs(f);
     f.printf("</global_preferences>\n");
     return 0;
 }
 
-const char *BOINC_RCSID_3fb442bb02 = "$Id: prefs.cpp 17740 2009-04-07 18:21:39Z davea $";
-
-
-
