@@ -170,6 +170,7 @@ int procinfo_setup(vector<PROCINFO>& pi) {
     PROCINFO p;
     char pidpath[1024];
     char buf[1024];
+    int pid = getpid();
 
     dir = opendir("/proc");
     if (!dir) return 0;
@@ -205,7 +206,7 @@ int procinfo_setup(vector<PROCINFO>& pi) {
                             p.page_fault_count = prusage.pr_majf + prusage.pr_minf;
                         }
                         fclose(fd);
-                        p.is_boinc_app = false;
+                        p.is_boinc_app = (p.id == pid || strcasestr(p.command, "boinc"));
                         pi.push_back(p);
                     }
                 }
@@ -230,7 +231,7 @@ int procinfo_setup(vector<PROCINFO>& pi) {
                     p.user_time = ps.utime / 100.;
                     p.kernel_time = ps.stime / 100.;
                     strlcpy(p.command, ps.comm, sizeof(p.command));
-                    p.is_boinc_app = false;
+                    p.is_boinc_app = (p.id == pid || strcasestr(p.command, "boinc"));
                     pi.push_back(p);
                 }
 #endif
@@ -281,7 +282,9 @@ void add_child_totals(PROCINFO& pi, vector<PROCINFO>& piv, int pid, int rlvl) {
 // fill in the given PROCINFO (which initially is zero except for id)
 // with totals from that process and all its descendants
 //
-void procinfo_app(PROCINFO& pi, vector<PROCINFO>& piv) {
+void procinfo_app(
+    PROCINFO& pi, vector<PROCINFO>& piv, char* graphics_exec_file
+) {
     unsigned int i;
 
     for (i=0; i<piv.size(); i++) {
@@ -298,6 +301,9 @@ void procinfo_app(PROCINFO& pi, vector<PROCINFO>& piv) {
             add_child_totals(pi, piv, pi.id, 0);
             return;
         }
+        if (!strcmp(p.command, graphics_exec_file)) {
+            p.is_boinc_app = true;
+        }
     }
 }
 
