@@ -4,6 +4,7 @@
 #include "error_numbers.h"
 #include "diagnostics_win.h"
 #include "str_util.h"
+#include "str_replace.h"
 #include "procinfo.h"
 
 using std::vector;
@@ -67,6 +68,11 @@ int get_procinfo_XP(vector<PROCINFO>& pi) {
     ULONG                   cbBuffer = 128*1024;    // 128k initial buffer
     PVOID                   pBuffer = NULL;
     PSYSTEM_PROCESSES       pProcesses = NULL;
+    static DWORD pid = 0;
+
+    if (!pid) {
+        pid = GetCurrentProcessId();
+    }
 #if 0
 	printf("FILETIME: %d\n", sizeof(FILETIME));
 	printf("LARGE_INTEGER: %d\n", sizeof(LARGE_INTEGER));
@@ -97,7 +103,7 @@ int get_procinfo_XP(vector<PROCINFO>& pi) {
             sizeof(p.command),
             NULL, NULL
         );
-		p.is_boinc_app = false;
+		p.is_boinc_app = (p.id == pid) || (strcasestr(p.command, "boinc") != NULL);
         pi.push_back(p);
         if (!pProcesses->NextEntryDelta) {
             break;
@@ -131,7 +137,10 @@ int procinfo_setup(vector<PROCINFO>& pi) {
 // scan the process table from the given point,
 // adding in CPU time and mem usage
 // 
-void add_proc_totals(PROCINFO& pi, vector<PROCINFO>& piv, int pid, int start) {
+void add_proc_totals(
+    PROCINFO& pi, vector<PROCINFO>& piv, int pid,
+    char* graphics_exec_file, int start
+) {
 	unsigned int i;
 	for (i=start; i<piv.size(); i++) {
 		PROCINFO& p = piv[i];
@@ -142,9 +151,12 @@ void add_proc_totals(PROCINFO& pi, vector<PROCINFO>& piv, int pid, int start) {
 			pi.working_set_size += p.working_set_size;
 			pi.page_fault_count += p.page_fault_count;
 			p.is_boinc_app = true;
-		} 
+		}
+        if (!strcmp(p.command, graphics_exec_file)) {
+            p.is_boinc_app = true;
+        }
 		if (p.parentid == pid) {
-			add_proc_totals(pi, piv, p.id, i+1);	// recursion - woo hoo!
+			add_proc_totals(pi, piv, p.id, graphics_exec_file, i+1);    // recursion - woo hoo!
 		}
 	}
 }
@@ -152,8 +164,8 @@ void add_proc_totals(PROCINFO& pi, vector<PROCINFO>& piv, int pid, int start) {
 // fill in the given PROCINFO (which initially is zero except for id)
 // with totals from that process and all its descendants
 //
-void procinfo_app(PROCINFO& pi, vector<PROCINFO>& piv) {
-	add_proc_totals(pi, piv, pi.id, 0);
+void procinfo_app(PROCINFO& pi, vector<PROCINFO>& piv, char* graphics_exec_file) {
+	add_proc_totals(pi, piv, pi.id, graphics_exec_file, 0);
 }
 
 // get totals of all non-BOINC processes
@@ -163,7 +175,7 @@ void procinfo_other(PROCINFO& pi, vector<PROCINFO>& piv) {
 	memset(&pi, 0, sizeof(pi));
 	for (i=0; i<piv.size(); i++) {
 		PROCINFO& p = piv[i];
-		if (!p.is_boinc_app) {
+		if (!p.is_boinc_app && p.id != 0) {     // PID 0 is idle process
 			pi.kernel_time += p.kernel_time;
 			pi.user_time += p.user_time;
 			pi.swap_size += p.swap_size;
