@@ -22,6 +22,7 @@
 #include "boinc_win.h"
 #endif
 
+#include "diagnostics.h"
 #include "win_util.h"
 
 
@@ -355,17 +356,19 @@ BOOL AddAceToWindowStation(HWINSTA hwinsta, PSID psid)
       pace = (ACCESS_ALLOWED_ACE *)HeapAlloc(
             GetProcessHeap(),
             HEAP_ZERO_MEMORY,
-            sizeof(ACCESS_ALLOWED_ACE) + GetLengthSid(psid) -
-                  sizeof(DWORD));
+            sizeof(ACCESS_ALLOWED_ACE) + GetLengthSid(psid) - sizeof(DWORD)
+      );
 
       if (pace == NULL)
          throw;
 
       pace->Header.AceType  = ACCESS_ALLOWED_ACE_TYPE;
       pace->Header.AceFlags = CONTAINER_INHERIT_ACE |
-                   INHERIT_ONLY_ACE | OBJECT_INHERIT_ACE;
-      pace->Header.AceSize  = sizeof(ACCESS_ALLOWED_ACE) +
-                   GetLengthSid(psid) - sizeof(DWORD);
+                              INHERIT_ONLY_ACE |
+                              OBJECT_INHERIT_ACE;
+      pace->Header.AceSize  = (WORD)sizeof(ACCESS_ALLOWED_ACE) + 
+                              (WORD)GetLengthSid(psid) - 
+                              (WORD)sizeof(DWORD);
       pace->Mask            = GENERIC_ALL;
 
       if (!CopySid(GetLengthSid(psid), &pace->SidStart, psid))
@@ -772,6 +775,7 @@ int suspend_or_resume_threads(DWORD pid, bool resume) {
     }
 
     do { 
+        if (!diagnostics_is_thread_exempt_suspend(te.th32ThreadID)) continue;
         if (te.th32OwnerProcessID == pid) {
             thread = pOT(THREAD_SUSPEND_RESUME, FALSE, te.th32ThreadID);
             resume ?  ResumeThread(thread) : SuspendThread(thread);
