@@ -1,4 +1,4 @@
-## $Id: setup_project.py 15702 2008-07-28 22:56:39Z davea $
+## $Id: setup_project.py 18481 2009-06-22 22:20:35Z davea $
 
 # module for setting up a new project (either a real project or a test project
 # see tools/makeproject, test/testbase.py).
@@ -19,20 +19,12 @@ errors.count = 0
 
 options.have_init = False
 options.install_method = None
-options.echo_verbose = 1
 options.is_test = False
 options.drop_db_first = False
 
 def init():
     if options.have_init: return
     options.have_init = True
-    options.tty = os.isatty(1)
-    options.echo_overwrite = options.tty and options.echo_verbose==1
-
-    # VERBOSE: 0 = print nothing
-    #          1 = print some (default
-    #              if output is a tty, overwrite lines.
-    #          2 = print all
 
     if options.install_method == 'copy':
         options.install_function = shutil.copy
@@ -43,22 +35,9 @@ def init():
     else:
         fatal_error("Invalid install method: %s"%options.install_method)
 
-prev_overwrite = False
 def verbose_echo(level, line):
-    global prev_overwrite
-    if level == 0:
-        if prev_overwrite:
-            print
-        print line
-        prev_overwrite = False
-    elif options.echo_verbose >= level:
-        if options.echo_overwrite:
-            print "\r                                                                               ",
-            print "\r", line,
-            sys.stdout.flush()
-            prev_overwrite = True
-        else:
-            print line
+    print line
+    sys.stdout.flush()
 
 def fatal_error(msg):
     errors.count += 1
@@ -126,7 +105,12 @@ def my_link(src,dest):
 def install(src, dest, unless_exists=False):
     if unless_exists and os.path.exists(dest):
         return
-    options.install_function(src, dest)
+    try:
+        options.install_function(src, dest)
+    except:
+        print 'failed to copy ' + src + ' to ' + dest
+        return
+
 
 def install_glob(glob_source, dest, failok=False):
     dest = os.path.join(dest, '') # append '/' if necessary
@@ -184,7 +168,7 @@ def account_file_name(url):
     return 'account_' + _url_to_filename(url) + '.xml'
 
 def srcdir(*dirs):
-    return apply(os.path.join,(boinc_path_config.TOP_SOURCE_DIR,)+dirs)
+    return apply(os.path.join,(options.srcdir,)+dirs)
 
 def builddir(*dirs):
     return apply(os.path.join,(boinc_path_config.TOP_BUILD_DIR,)+dirs)
@@ -270,6 +254,8 @@ def create_project_dirs(dest_dir):
         [   '',
             'cgi-bin',
             'bin',
+            'py',
+            'py/Boinc',
             'templates',
             'upload',
             'download',
@@ -335,6 +321,7 @@ def install_boinc_files(dest_dir, web_only):
     install_glob(srcdir('html/user/*.png'), dir('html/user/img'))
     install_glob(srcdir('html/user/*.gif'), dir('html/user/img'))
     install_glob(srcdir('html/user/img/*.*'), dir('html/user/img'))
+    os.system("rm -f "+dir('html/languages/translations/*'))
     install_glob(srcdir('html/languages/translations/*.po'), dir('html/languages/translations/'))
 
     # copy Python stuff
@@ -342,11 +329,16 @@ def install_boinc_files(dest_dir, web_only):
         [ 'start' ])
     force_symlink(dir('bin', 'start'), dir('bin', 'stop'))
     force_symlink(dir('bin', 'start'), dir('bin', 'status'))
-    map(lambda (s): install(srcdir('py/Boinc',s), dir('bin',s)),
-        [ 'add_util.py', 'boinc_db.py', 'boinc_project_path.py',
+    map(lambda (s): install(srcdir('py/Boinc',s), dir('py/Boinc',s)),
+        [ '__init__.py', 'add_util.py', 'boinc_db.py', 'boinc_project_path.py',
           'boincxml.py', 'configxml.py', 'database.py',
           'db_base.py', 'db_mid.py', 'projectxml.py',
           'sched_messages.py', 'tools.py', 'util.py' ])
+    print >>open(dir('bin', 'boinc_path_config.py'), 'w'), '''
+# Generated by make_project
+import sys, os
+sys.path.insert(0, os.path.join('%s', 'py'))
+''' % dest_dir
 
     if web_only:
         return
@@ -366,13 +358,14 @@ def install_boinc_files(dest_dir, web_only):
           'sample_bitwise_validator', 'sample_trivial_validator',
           'file_deleter', 'sample_dummy_assimilator',
           'sample_assimilator', 'sample_work_generator',
-          'single_job_assimilator', 'pymw_assimilator',
+          'single_job_assimilator', 
+          'assimilator.py', 'pymw_assimilator.py',
           'update_stats', 'db_dump', 'db_purge', 'show_shmem', 'census' ])
     map(lambda (s): install(srcdir('tools',s), dir('bin',s)),
         [ 'create_work', 'xadd', 'dbcheck_files_exist', 'run_in_ops',
           'update_versions', 'parse_config', 'grep_logs', 'db_query',
           'watch_tcp', 'sign_executable', 'dir_hier_move',
-          'pymw_setup', 'dir_hier_path' ])
+          'dir_hier_path' ])
     map(lambda (s): install(srcdir('lib',s), dir('bin',s)),
         [ 'crypt_prog' ])
     map(lambda (s): install(srcdir('sched',s), dir('',s)),
@@ -501,7 +494,6 @@ class Project:
             self.dir('html/user/rss_main.php'))
         install(srcdir('html/ops', 'sample_server_status.php'),
             self.dir('html/user/server_status.php'))
-        install(srcdir('html/languages/project_specific_translations/sample_en.po'), self.dir('html/languages/project_specific_translations/en.po'))
         install(srcdir('tools/project.xml'), self.dir('project.xml'))
         if not self.production:
             install(srcdir('test/uc_result'), self.dir('templates/uc_result'))
@@ -535,6 +527,7 @@ class Project:
 
         verbose_echo(1, "Setting up database")
         database.create_database(
+            srcdir = options.srcdir,
             config = self.config.config,
             drop_first = options.drop_db_first
             )
