@@ -17,9 +17,6 @@
 
 #include <cstdio>
 
-#include "sched_shmem.h"
-#include "server_types.h"
-
 extern void handle_request(
     FILE* fin, FILE* fout, char* code_sign_key
 );
